"""
Tests
"""

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_label_ar
from ArWikiCats.legacy_bots.ma_bots2.country2_label_bot import c_2_1_lab

test_data = {
    "american documentary television series": "مسلسلات تلفزيونية وثائقية أمريكية",
    "american propaganda films": "أفلام دعائية أمريكية",
    "brazilian television shows": "عروض تلفزيونية برازيلية",
    "british television series": "مسلسلات تلفزيونية بريطانية",
    "documentary television series": "مسلسلات تلفزيونية وثائقية",
}

fast_and_data = {
    "akrotiri and dhekelia": "أكروتيري ودكليا",
    "andaman and nicobar islands": "جزر أندمان ونيكوبار",
    "anime and manga": "أنمي ومانغا",
    "antigua and barbuda": "أنتيغوا وباربودا",
    "argyll and bute": "أرغيل وبوت",
    "art museums and galleries": "متاحف فنية ومعارض",
    "bosnia and herzegovina soldiers": "مجندون بوسنيون",
    "bosnia and herzegovina": "البوسنة والهرسك",
    "brighton and hove": "برايتون أند هوف",
    "perth and kinross": "بيرث وكينروس",
    "ross and cromarty": "روس وكرومارتي",
    "saint kitts and nevis": "سانت كيتس ونيفيس",
    "saint pierre and miquelon": "سان بيير وميكلون",
    "saint vincent and grenadines": "سانت فنسنت وجزر غرينادين",
    "saxe-coburg and gotha": "دوقية ساكسونيا كوبورغ وغوتا",
    "science and technology": "العلوم والتقانة",
    "sports clubs and teams": "أندية وفرق رياضية",
    "são tomé and príncipe": "ساو تومي وبرينسيب",
    "trinidad and tobago coast guard": "خفر السواحل الترنيدادي",
    "trinidad and tobago descent": "أصل ترنيدادي",
    "trinidad and tobago": "ترينيداد وتوباغو",
    "turks and caicos islands": "جزر توركس وكايكوس",
    "tyne and wear": "تاين و وير",
}

fast_data_c_2_1_lab = {
    "australian royal navy": "البحرية الملكية الأسترالية",
    "swedish royal navy": "البحرية الملكية السويدية",
    "thai royal navy": "البحرية الملكية التايلندية",
    "1st century bc": "القرن 1 ق م",
    "6th century bc": "القرن 6 ق م",
    "7th century bc": "القرن 7 ق م",
    "8th century bc": "القرن 8 ق م",
    "abbasid caliphate": "الدولة العباسية",
    "algerian civil war": "الحرب الأهلية الجزائرية",
    "amazonas (brazilian state)": "الأمازون (ولاية)",
    "american civil war": "الحرب الأهلية الأمريكية",
    "american football executives": "مسيرو كرة قدم أمريكية",
    "american football players": "لاعبو كرة قدم أمريكية",
    "american revolution": "الثورة الأمريكية",
    "andorra la vella": "أندورا لا فيلا",
    "ang thong province": "محافظة أنغ ثونغ",
    "arab world": "الوطن العربي",
    "archelaus of macedon": "أرخيلاوس الأول المقدوني",
    "asian football confederation": "الاتحاد الآسيوي لكرة القدم",
    "asian tennis federation": "الاتحاد الآسيوي لكرة المضرب",
    "athletics navigational boxes": "صناديق تصفح ألعاب قوى",
    "australian capital territory": "إقليم العاصمة الأسترالية",
    "australian national university": "جامعة أستراليا الوطنية",
    "australian royal air force": "القوات الجوية الملكية الأسترالية",
    "australian rules football": "كرة القدم الأسترالية",
    "aviation accidents or incidents": "حوادث طيران",
    "azerbaijan soviet socialist republic": "الجمهورية الأذرية السوفيتية الاشتراكية",
    "b. r. ambedkar": "أمبيدكار",
    "baal shem tov": "بعل شيم توف",
    "baja california sur": "ولاية باخا كاليفورنيا سور",
    "bangka belitung islands": "بانغكا - بليتونغ",
    "banteay meanchey province": "محافظة بانتياي مينتشي",
    "boadilla del monte": "بواديلا ديل مونتي",
    "bocas del toro province": "محافظة بوكاس ديل تورو",
    "british empire": "الإمبراطورية البريطانية",
    "british virgin islands": "جزر العذراء البريطانية",
    "buenos aires province": "مقاطعة بوينس آيرس",
    "byzantine empire": "الإمبراطورية البيزنطية",
    "cayman islands": "جزر كايمان",
    "central african republic": "جمهورية إفريقيا الوسطى",
    "channel islands": "جزر القنال الإنجليزي",
    "cocos (keeling) islands": "جزر كوكوس",
    "cook islands": "جزر كوك",
    "covid-19 pandemic": "جائحة فيروس كورونا",
    "czech republic": "التشيك",
    "dominican republic": "جمهورية الدومينيكان",
    "dutch east indies": "الهند الشرقية الهولندية",
    "dutch republic": "جمهورية هولندا",
    "east midlands": "ميدلاند الشرقية",
    "european union": "الاتحاد الأوروبي",
    "falkland islands": "جزر فوكلاند",
    "faroe islands": "جزر فارو",
    "fatimid caliphate": "الدولة الفاطمية",
    "federated states-of micronesia": "ولايات ميكرونيسيا المتحدة",
    "gaza strip": "قطاع غزة",
    "holy roman empire": "الإمبراطورية الرومانية المقدسة",
    "israel–hamas war": "الحرب الفلسطينية الإسرائيلية",
    "marshall islands": "جزر مارشال",
    "middle east": "الشرق الأوسط",
    "new republic": "ذا نيو ريببلك",
    "new york review of books": "نيويورك ريفيو أوف بوكس",
    "northern mariana islands": "جزر ماريانا الشمالية",
    "oliveira de azeméis": "أوليفيرا دي ازميس",
    "olympic games": "الألعاب الأولمبية",
    "orange free state": "دولة البرتقال الحرة",
    "order of": "وسام",
    "osama bin laden": "أسامة بن لادن",
    "ottoman empire": "الدولة العثمانية",
    "palestinian national authority": "السلطة الوطنية الفلسطينية",
    "papua new guinea": "بابوا غينيا الجديدة",
    "paschim medinipur district": "مقاطعة باشيم مدينبور",
    "pays de la loire": "وادي اللوار",
    "pitcairn islands": "جزر بيتكيرن",
    "polish air force": "القوات الجوية البولندية",
    "polish–lithuanian commonwealth": "الكومنولث البولندي الليتواني",
    "pope alexander vi": "إسكندر السادس",
    "pope john paul ii": "البابا يوحنا بولص الثاني",
    "pope leo xiii": "ليون الثالث عشر",
    "pope paul vi": "بولس السادس",
    "pope pius xi": "بيوس الحادي عشر",
    "preah vihear province": "محافظة برياه فيهير",
    "prince edward island": "جزيرة الأمير إدوارد",
    "principality of serbia": "إمارة صربيا",
    "province of canada": "مقاطعة كندا",
    "province of tarragona": "طراغونة (مقاطعة)",
    "puerto rican descent": "أصل بورتوريكي",
    "purba medinipur district": "مقاطعة بوبا مدينبور",
    "póvoa de varzim": "بوفوا دي فارزيم",
    "rajanna sircilla district": "مقاطعة راجانا سيرسيلا",
    "ras al khaimah": "رأس الخيمة (مدينة)",
    "revolutionary socialist party (india)": "الحزب الاشتراكي الثوري",
    "rhondda cynon taf": "روندا كينون تاف",
    "richmond upon thames": "ريتشموند (لندن)",
    "rio de janeiro (city)": "ريو دي جانيرو",
    "rio de janeiro (state)": "ولاية ريو دي جانيرو",
    "rio de janeiro": "ريو دي جانيرو",
    "rio grande do norte": "ريو غراندي دو نورتي",
    "rio grande do sul": "ريو غراندي دو سول",
    "rio negro (amazon)": "ريو نيغرو (الأمازون)",
    "romanian naval forces": "البحرية الرومانية",
    "royal air force": "القوات الجوية الملكية",
    "royal college of nursing": "كلية التمريض الملكية",
    "rugby union players": "لاعبو اتحاد رجبي",
    "russian air force": "القوات الجوية الروسية",
    "russian soviet federative socialist republic": "جمهورية روسيا السوفيتية الاتحادية الاشتراكية",
    "río de la plata": "ريو دي لا بلاتا (نهر)",
    "río negro province": "محافظة ريو نيغرو",
    "salt lake city": "سولت ليك (مدينة)",
    "san francisco bay area": "منطقة خليج سان فرانسيسكو",
    "san luis potosí": "ولاية سان لويس بوتوسي",
    "san luis province": "محافظة سان لويس",
    "santa catarina (state)": "ولاية سانتا كاتارينا",
    "santa cruz de tenerife": "سانتا كروث دي تينيريفه",
    "santa fe province": "محافظة سانتا-في",
    "santa maria da feira": "سانتا ماريا دا فييرا",
    "santiago de cuba": "سانتياغو دي كوبا",
    "santiago del estero province": "محافظة سانتياغو ديل استيرو",
    "santiago do cacém": "سانتياغو دو كاسيم",
    "santiago metropolitan region": "إقليم سانتياغو متروبوليتان",
    "sasanian empire": "الإمبراطورية الساسانية",
    "satu mare county": "مقاطعة ساتو ماري",
    "science fiction magazines": "مجلات خيال علمي",
    "second bulgarian empire": "الإمبراطورية البلغارية الثانية",
    "second polish republic": "الجمهورية البولندية الثانية",
    "security service of ukraine": "خدمة أمن أوكرانيا",
    "siem reap province": "محافظة سيم رياب",
    "singapore air force personnel": "أفراد القوات الجوية السنغافورية",
    "sixth dynasty of egypt": "الأسرة المصرية السادسة",
    "sogn og fjordane": "سوغن وفيوردانه",
    "solomon islands": "جزر سليمان",
    "soviet union": "الاتحاد السوفيتي",
    "spanish civil war": "الحرب الأهلية الإسبانية",
    "sri lanka air force": "القوات الجوية السريلانكية",
    "sri lanka navy": "البحرية السريلانكية",
    "sri lankan civil war": "الحرب الأهلية السريلانكية",
    "sri lankan descent": "أصل سريلانكي",
    "st. johns river": "نهر سانت جونز",
    "state lower houses": "مجالس نواب الولايات",
    "sultanate of zanzibar": "سلطنة زنجبار",
    "syrian civil war": "الحرب الأهلية السورية",
    "são paulo (city)": "ساو باولو",
    "são paulo (state)": "ولاية ساو باولو",
    "tai po district": "مقاطعة تاي بو",
    "telugu desam party": "حزب تيلوغو ديسام",
    "thai royal air force": "القوات الجوية الملكية التايلندية",
    "third dynasty of egypt": "الأسرة المصرية الثالثة",
    "thirteen colonies": "المستعمرات الثلاث عشرة",
    "thirtieth dynasty of egypt": "الأسرة المصرية الثلاثون",
    "turkish air force": "القوات الجوية التركية",
    "twelfth dynasty of egypt": "الأسرة المصرية الثانية عشر",
    "twenty-fifth dynasty of egypt": "الأسرة المصرية الخامسة والعشرون",
    "twenty-fourth dynasty of egypt": "الأسرة المصرية الرابعة والعشرون",
    "twenty-second dynasty of egypt": "الأسرة المصرية الثانية والعشرون",
    "u.s. virgin islands": "جزر العذراء الأمريكية",
    "ukrainian soviet socialist republic": "جمهورية أوكرانيا السوفيتية الاشتراكية",
    "united arab emirates": "الإمارات العربية المتحدة",
    "united kingdom government": "حكومة المملكة المتحدة",
    "united kingdom": "المملكة المتحدة",
    "united nations": "الأمم المتحدة",
    "united states virgin islands": "جزر العذراء الأمريكية",
    "united states": "الولايات المتحدة",
    "west bank": "الضفة الغربية",
    "west indies": "الهند الغربية",
    "west midlands (county)": "مقاطعة ميدلاند الغربية",
    "west midlands (region)": "منطقة ميدلاند الغربية",
}


@pytest.mark.parametrize("category, expected", fast_data_c_2_1_lab.items(), ids=fast_data_c_2_1_lab.keys())
@pytest.mark.fast
def test_c_2_1_lab(category: str, expected: str) -> None:
    label = c_2_1_lab(category, with_years=True)
    assert label == expected


@pytest.mark.parametrize("category, expected", test_data.items(), ids=test_data.keys())
@pytest.mark.fast
def test_test_data(category: str, expected: str) -> None:
    label = resolve_label_ar(category)
    assert label == expected


to_test = [
    ("test_c_2_1_lab", fast_data_c_2_1_lab, c_2_1_lab),
    ("test_c_2_1_lab", fast_and_data, c_2_1_lab),
]


@pytest.mark.parametrize("name,data, callback", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)
    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""Additional key-label mappings for companies, media and professions."""

from __future__ import annotations

from ...helps import len_print
from ..sports.games_labs import SUMMER_WINTER_TABS
from ..utils.json_dir import open_json_file

companies_keys3 = {
    "railway": "السكك الحديدية",
    "transport": "النقل",
    "railway stations": "محطات السكك الحديدية",
    "road": "الطرق",
    "road transport": "النقل البري",
    "entertainment": "ترفيه",
    "aviation": "الطيران",
    "airlines": "طيران",
    "bus": "الباصات",
    "design": "تصميم",
    "aviation accidents": "حوادث طيران",
    "vehicle": "المركبات",
    "transport companies": "شركات النقل",
    "railway companies": "شركات السكك الحديدية",
    "entertainment companies": "شركات ترفيه",
    "transport disasters": "كوارث نقل",
    "railway accidents": "حوادث سكك حديد",
    "design companies": "شركات تصميم",
    "vehicle manufacturing": "تصنيع المركبات",
    "vehicle manufacturing companies": "شركات تصنيع المركبات",
    "water transport": "النقل المائي",
    "holding": "قابضة",
    "motor vehicle": "السيارات",
    "vehicle manufacturers": "مصانع المركبات",
    "holding companies": "شركات قابضة",
    "truck": "الشاحنات",
    "rolling stock": "القطارات",
    "defunct airlines": "طيران سابقة",
    "shipping": "النقل البحري",
    "government-owned": "مملوكة للحكومة",
    "defunct airlines of": "طيران سابقة في",
    "bus stations": "محطات الباصات",
    "motor vehicle manufacturers": "مصانع السيارات",
    "government-owned companies": "شركات مملوكة للحكومة",
    "privately held": "خاصة",
    "privately held companies": "شركات خاصة",
    "shipping companies": "شركات النقل البحري",
    "ferry transport": "النقل بالعبارات",
    "airline": "الخطوط الجوية",
    "locomotive": "القاطرات",
    "defunct railway": "سكك حديد سابقة",
    "airlines accidents": "حوادث طيران",
    "bus companies": "شركات الباصات",
    "bus manufacturers": "مصانع الباصات",
    "truck manufacturers": "مصانع الشاحنات",
    "distance education": "التعليم عن بعد",
    "defunct transport": "نقل سابقة",
    "rolling stock manufacturers": "مصانع القطارات",
    "locomotive manufacturers": "مصانع القاطرات",
    "defunct motor vehicle": "سيارات سابقة",
    "distance education institutions": "مؤسسات تعليم عن بعد",
    "cargo airlines": "الشحن الجوي",
    "railway accident": "حوادث سكك حديد",
    "aviation accident": "حوادث طيران",
    "transport stations": "محطات النقل",
    "defunct shipping": "نقل بحري سابقة",
    "defunct rolling stock": "قطارات سابقة",
    "defunct locomotive": "قاطرات سابقة",
    "road stations": "محطات الطرق",
    "transport accidents": "حوادث نقل",
    "rail industry": "السكك الحديدية",
    "aviation companies": "شركات الطيران",
    "entertainment franchises": "امتيازات ترفيه",
    "defunct bus": "باصات سابقة",
    "defunct entertainment": "الترفيه سابقة",
    "road accidents": "حوادث طرق",
    "defunct aviation": "طيران سابقة",
    "defunct government-owned": "مملوكة للحكومة سابقة",
    "transport policy": "سياسات النقل",
    "airline companies": "شركات الخطوط الجوية",
    "defunct airline": "خطوط جوية سابقة",
    "rail industry companies": "شركات السكك الحديدية",
    "defunct truck": "شاحنات سابقة",
    "defunct cargo airlines": "شحن جوي سابقة",
    "defunct privately held": "خاصة سابقة",
    "defunct rail industry": "سكك حديد سابقة",
    "rail industry manufacturing": "تصنيع السكك الحديدية",
    "rail industry manufacturing companies": "شركات تصنيع السكك الحديدية",
    "transport accident": "حوادث نقل",
    "airline tickets": "تذاكر الخطوط الجوية",
    "defunct cargo airlines of": "شحن جوي سابقة في",
    "defunct design": "تصميم سابقة",
    "design institutions": "مؤسسات تصميم",
    "motor vehicle companies": "شركات السيارات",
    "vehicle companies": "شركات المركبات",
    "motor vehicle manufacturing": "تصنيع السيارات",
    "transport tickets": "تذاكر النقل",
    "railway franchises": "امتيازات السكك الحديدية",
    "road transport companies": "شركات النقل البري",
    "water transport companies": "شركات النقل المائي",
}

tab2 = {
    "colleges": "كليات",
    "distance education": "التعليم عن بعد",
    "education controversies": "خلافات متعلقة بالتعليم",
    "federal colleges": "كليات فيدرالية",
    "federal libraries": "مكتبات فيدرالية",
    "federal schools": "مدارس فيدرالية",
    "federal universities": "جامعات فيدرالية",
    "federal universities and colleges": "جامعات وكليات فيدرالية",
    "government colleges": "كليات حكومية",
    "government libraries": "مكتبات حكومية",
    "government schools": "مدارس حكومية",
    "government universities": "جامعات حكومية",
    "government universities and colleges": "جامعات وكليات حكومية",
    "islamic colleges": "كليات إسلامية",
    "islamic libraries": "مكتبات إسلامية",
    "islamic schools": "مدارس إسلامية",
    "islamic universities": "جامعات إسلامية",
    "islamic universities and colleges": "جامعات وكليات إسلامية",
    "libraries": "مكتبات",
    "national colleges": "كليات وطنية",
    "national libraries": "مكتبات وطنية",
    "national schools": "مدارس وطنية",
    "national universities": "جامعات وطنية",
    "national universities and colleges": "جامعات وكليات وطنية",
    "public colleges": "كليات حكومية",
    "public libraries": "مكتبات حكومية",
    "public schools": "مدارس حكومية",
    "public universities": "جامعات حكومية",
    "public universities and colleges": "جامعات وكليات حكومية",
    "schools": "مدارس",
    "Standardized tests": "اختبارات قياسية",
    "universities": "جامعات",
    "universities and colleges": "جامعات وكليات",
}

pop_final_3_update = {
    "Agricultural buildings and structures on the-national-register-of-historic-places in": "مبان ومنشآت زراعية  في السجل الوطني للأماكن التاريخية في ",
    "agricultural buildings and structures": "مبان ومنشآت زراعية",
    "architecture museums": "متاحف معمارية",
    "astronomical observatories": "مراصد فلكية",
    "bank buildings on the-national-register-of-historic-places in": "مباني بنوك  في السجل الوطني للأماكن التاريخية في ",
    "bank buildings": "مباني بنوك",
    "bridge disasters": "كوارث جسور",
    "bridge": "جسور",
    "bridges on the-national-register-of-historic-places in": "جسور  في السجل الوطني للأماكن التاريخية في ",
    "bridges": "جسور",
    "buildings and structures on the-national-register-of-historic-places in": "مبان ومنشآت  في السجل الوطني للأماكن التاريخية في ",
    "buildings and structures": "مبان ومنشآت",
    "buildings on the-national-register-of-historic-places in": "مباني  في السجل الوطني للأماكن التاريخية في ",
    "buildings": "مباني",
    "burial monuments and structures": "معالم ومنشآت أماكن الدفن",
    "burials": "مدفونون",
    "canals on the-national-register-of-historic-places in": "ممرات مائية  في السجل الوطني للأماكن التاريخية في ",
    "canals": "ممرات مائية",
    "Cemeteries on the-national-register-of-historic-places in": "مقابر  في السجل الوطني للأماكن التاريخية في ",
    "cemeteries": "مقابر",
    "christian buildings and structures": "مبان ومنشآت مسيحية",
    "christian buildings": "مباني مسيحية",
    "christian Cemeteries": "مقابر مسيحية",
    "christian colleges": "كليات مسيحية",
    "christian Hospitals": "مستشفيات مسيحية",
    "christian libraries": "مكتبات مسيحية",
    "christian Museums": "متاحف مسيحية",
    "christian schools": "مدارس مسيحية",
    "christian universities and colleges": "جامعات وكليات مسيحية",
    "christian universities": "جامعات مسيحية",
    "clock towers": "أبراج ساعة",
    "Clubhouses on the-national-register-of-historic-places in": "نوادي  في السجل الوطني للأماكن التاريخية في ",
    "clubhouses": "نوادي",
    "colleges": "كليات",
    "commercial buildings on the-national-register-of-historic-places in": "مباني تجارية  في السجل الوطني للأماكن التاريخية في ",
    "commercial buildings": "مباني تجارية",
    "defunct Astronomical observatories": "مراصد فلكية سابقة",
    "defunct Hospitals": "مستشفيات سابقة",
    "defunct Hotels": "فنادق سابقة",
    "defunct islamic schools": "مدارس إسلامية سابقة",
    "defunct libraries": "مكتبات سابقة",
    "defunct Museums": "متاحف سابقة",
    "defunct private universities and colleges": "جامعات وكليات خاصة سابقة",
    "defunct public schools": "مدارس حكومية سابقة",
    "defunct public universities and colleges": "جامعات وكليات حكومية سابقة",
    "defunct public universities": "جامعات حكومية سابقة",
    "defunct restaurants": "مطاعم سابقة",
    "defunct schools": "مدارس سابقة",
    "defunct sports venues": "ملاعب رياضية سابقة",
    "defunct supermarkets": "محلات سوبر ماركت سابقة",
    "defunct transportation": "وسائل نقل سابقة",
    "defunct universities and colleges": "جامعات وكليات سابقة",
    "defunct universities": "جامعات سابقة",
    "distance education": "التعليم عن بعد",
    "education controversies": "خلافات متعلقة بالتعليم",
    "facilities on the-national-register-of-historic-places in": "مرافق  في السجل الوطني للأماكن التاريخية في ",
    "facilities": "مرافق",
    "federal colleges": "كليات فيدرالية",
    "federal universities and colleges": "جامعات وكليات فيدرالية",
    "federal universities": "جامعات فيدرالية",
    "ferries": "عبارات",
    "fountains on the-national-register-of-historic-places in": "نوافير  في السجل الوطني للأماكن التاريخية في ",
    "fountains": "نوافير",
    "government colleges": "كليات حكومية",
    "government schools": "مدارس حكومية",
    "government universities and colleges": "جامعات وكليات حكومية",
    "government universities": "جامعات حكومية",
    "history museums": "متاحف تاريخية",
    "hospitals": "مستشفيات",
    "hotels": "فنادق",
    "Industrial buildings and structures on the-national-register-of-historic-places in": "مبان ومنشآت صناعية  في السجل الوطني للأماكن التاريخية في ",
    "industrial buildings and structures": "مبان ومنشآت صناعية",
    "islamic education": "تعليم إسلامي",
    "islamic libraries": "مكتبات إسلامية",
    "islamic schools": "مدارس إسلامية",
    "islamic universities and colleges": "جامعات وكليات إسلامية",
    "islamic universities": "جامعات إسلامية",
    "laboratories": "مختبرات",
    "libraries on the-national-register-of-historic-places in": "مكتبات  في السجل الوطني للأماكن التاريخية في ",
    "libraries": "مكتبات",
    "lighthouses on the-national-register-of-historic-places in": "منارات  في السجل الوطني للأماكن التاريخية في ",
    "lighthouses": "منارات",
    "medical education": "تعليم طبي",
    "memorials and cemeteries": "نصب تذكارية ومقابر",
    "memorials on the-national-register-of-historic-places in": "نصب تذكارية  في السجل الوطني للأماكن التاريخية في ",
    "memorials": "نصب تذكارية",
    "military and war museums": "متاحف عسكرية وحربية",
    "mines": "مناجم",
    "monuments and memorials on the-national-register-of-historic-places in": "معالم أثرية ونصب تذكارية  في السجل الوطني للأماكن التاريخية في ",
    "monuments and memorials": "معالم أثرية ونصب تذكارية",
    "monuments and structures": "معالم أثرية ومنشآت",
    "monuments": "معالم أثرية",
    "Museums on the-national-register-of-historic-places in": "متاحف  في السجل الوطني للأماكن التاريخية في ",
    "museums": "متاحف",
    "national colleges": "كليات وطنية",
    "national libraries": "مكتبات وطنية",
    "national schools": "مدارس وطنية",
    "national universities and colleges": "جامعات وكليات وطنية",
    "national universities": "جامعات وطنية",
    "nature centers": "مراكز طبيعية",
    "outdoor sculptures": "منحوتات خارجية",
    "palaces": "قصور",
    "places of worship": "أماكن عبادة",
    "private universities and colleges": "جامعات وكليات خاصة",
    "public colleges": "كليات حكومية",
    "public libraries": "مكتبات حكومية",
    "public schools": "مدارس حكومية",
    "public universities and colleges": "جامعات وكليات حكومية",
    "public universities": "جامعات حكومية",
    "recording studios": "استديوهات تسجيل",
    "restaurants on the-national-register-of-historic-places in": "مطاعم  في السجل الوطني للأماكن التاريخية في ",
    "restaurants": "مطاعم",
    "Road bridges on the-national-register-of-historic-places in": "جسور طرق  في السجل الوطني للأماكن التاريخية في ",
    "road bridges": "جسور طرق",
    "road incidents": "حوادث طرق",
    "roads on the-national-register-of-historic-places in": "طرق  في السجل الوطني للأماكن التاريخية في ",
    "roads": "طرق",
    "schools": "مدارس",
    "science museums": "متاحف علمية",
    "sculpture": "منحوتات",
    "skyscraper hotels": "فنادق ناطحات سحاب",
    "skyscrapers": "ناطحات سحاب",
    "sports museums": "متاحف رياضية",
    "sports venues on the-national-register-of-historic-places in": "ملاعب رياضية  في السجل الوطني للأماكن التاريخية في ",
    "sports venues": "ملاعب رياضية",
    "standardized tests": "اختبارات قياسية",
    "state universities and colleges": "جامعات وكليات ولايات",
    "structures on the-national-register-of-historic-places in": "منشآت  في السجل الوطني للأماكن التاريخية في ",
    "structures": "منشآت",
    "studios": "استديوهات",
    "supermarkets": "محلات سوبر ماركت",
    "synagogues on the-national-register-of-historic-places in": "كنس  في السجل الوطني للأماكن التاريخية في ",
    "synagogues": "كنس",
    "theatres on the-national-register-of-historic-places in": "مسارح  في السجل الوطني للأماكن التاريخية في ",
    "theatres": "مسارح",
    "towers on the-national-register-of-historic-places in": "أبراج  في السجل الوطني للأماكن التاريخية في ",
    "towers": "أبراج",
    "transport buildings and structures": "مبان ومنشآت نقل",
    "transportation disasters": "كوارث وسائل نقل",
    "transportation museums": "متاحف النقل",
    "transportation on the-national-register-of-historic-places in": "وسائل نقل  في السجل الوطني للأماكن التاريخية في ",
    "transportation": "وسائل نقل",
    "universities and colleges": "جامعات وكليات",
    "universities": "جامعات",
}

ALBUMS_TYPE: dict[str, str] = {
    "folktronica": "فولكترونيكا",
    "concept": "مفاهيمية",
    "surprise": "مفاجئة",
    "comedy": "كوميدية",
    "mixtape": "ميكستايب",
    "remix": "ريمكس",
    "animation": "رسوم متحركة",
    "video": "فيديو",
    "compilation": "تجميعية",
    "live": "مباشرة",
    "jazz": "جاز",
    "eps": "أسطوانة مطولة",
    "folk": "فولك",
}

BUSINESSPEOPLE_INDUSTRIES: dict[str, str] = {
    "video game": "ألعاب الفيديو",
    "real estate": "العقارات",
    "financial": "المالية",
    "metals": "المعادن",
    "entertainment": "الترفيه",
    "fashion": "الأزياء",
    "computer": "كمبيوتر",
    "cosmetics": "مستحضرات التجميل",
}

FILM_PRODUCTION_COMPANY: dict[str, str] = {
    "Yash Raj": "ياش راج",
    "Illumination Entertainment": "إليمونيشن للترفيه",
    "Walt Disney Animation Studios": "استديوهات والت ديزني للرسوم المتحركة",
    "Carolco Pictures": "كارلوكو بيكشرز",
    "Aardman Animations": "آردمان انيمشنز",
    "Soyuzmultfilm": "سويز مولتفيلم",
    "Weinstein Company": "شركة وينشتاين",
    "Castle Rock Entertainment": "كاسل روك للترفيه",
    "United Artists": "يونايتد آرتيست",
    "Mosfilm": "موسفيلم",
    "National Geographic Society": "منظمة ناشيونال جيوغرافيك",
    "Showtime (TV network)": "شوتايم",
    "Touchstone Pictures": "توتشستون بيكشرز",
    "Rooster Teeth": "أسنان الديك",
    "Blue Sky Studios": "استديوهات بلو سكاي",
    "Bad Robot Productions": "باد روبوت للإنتاج",
    "TMS Entertainment": "تي أم أس إنترتنيمنت",
    "Sony Pictures Entertainment": "سوني بيكشرز إنترتنمنت",
    "sony pictures animation": "سوني بيكشرز أنيماشين",
    "Toei Company": "شركة توي",
    "Toho": "توهو",
    "Universal Studios": "يونيفرسل ستوديوز",
    "Walt Disney Company": "ديزني",
    "Paramount Pictures": "باراماونت بيكتشرز",
    "20th Century Fox": "تونتيث سينتشوري فوكس",
    "DreamWorks Animation": "دريمووركس أنيماشين",
    "Pixar": "بيكسار",
    "Metro-Goldwyn-Mayer": "مترو غولدوين ماير",
    "Lucasfilm": "لوكاس فيلم",
    "Amblin Entertainment": "أمبلين للترفيه",
    "DreamWorks": "دريم ووركس",
    "Funimation": "شركة فنميشن للترفيه",
    "Columbia Pictures": "كولومبيا بيكتشرز",
    "Marvel Studios": "استوديوهات مارفل",
    "HBO": "هوم بوكس أوفيس",
    "Warner Bros.": "وارنر برذرز",
}


def build_pop_final_3() -> dict[str, str]:
    """Build the main mapping used for pop culture categories."""

    registry = open_json_file("population/pop_final_3.json") or {}

    for industry, label in BUSINESSPEOPLE_INDUSTRIES.items():
        registry[f"{industry} businesspeople"] = f"شخصيات أعمال في {label}"
        registry[f"{industry} industry businesspeople"] = f"شخصيات أعمال في صناعة {label}"

    for company, label in FILM_PRODUCTION_COMPANY.items():
        registry[company] = label
        registry[f"{company} films"] = f"أفلام {label}"

    registry.update(SUMMER_WINTER_TABS)
    registry.update(companies_keys3)
    registry.update(tab2)
    registry.update(pop_final_3_update)

    return registry


pop_final_3: dict[str, str] = build_pop_final_3()

Ambassadors_tab: dict[str, str] = {}

len_print.data_len(
    "all_keys3.py",
    {
        "pop_final_3": pop_final_3,
        "ALBUMS_TYPE": ALBUMS_TYPE,
        "FILM_PRODUCTION_COMPANY": FILM_PRODUCTION_COMPANY,
        "Ambassadors_tab": Ambassadors_tab,
        "BUSINESSPEOPLE_INDUSTRIES": BUSINESSPEOPLE_INDUSTRIES,
    },
)

__all__ = [
    "pop_final_3",
    "ALBUMS_TYPE",
    "FILM_PRODUCTION_COMPANY",
    "Ambassadors_tab",
    "BUSINESSPEOPLE_INDUSTRIES",
]



"""Unit tests for the refactored :mod:`ArWikiCats.fix.fixtitle` helpers."""

from __future__ import annotations

from ArWikiCats.fix.fixtitle import add_fee, fix_it, fixlabel


def test_fix_it_applies_expected_normalizations() -> None:
    """``fix_it`` should apply key replacements from the refactor."""
    data = [
        ("الشعر العربي", "", "شعر العربي"),
        ("هجمات في باريس", "attacks on paris", "هجمات على باريس"),
        ("اقتصاد اليابان حسب الولاية", "", "اقتصاد اليابان حسب المحافظة"),
        ("حرب 1990-91", "", "حرب 1990–91"),
    ]
    for raw_label, en_label, expected in data:
        assert fix_it(raw_label, en_label) == expected


def test_fixlab_rejects_invalid_labels() -> None:
    """``fixlabel`` should discard labels with latin letters or stray dashes."""
    data = [
        "Label مع حروف انجليزية",
        "–1990 في القاهرة",
    ]
    for raw_label in data:
        assert fixlabel(raw_label) == ""


def test_fixlab_pipeline_strips_namespace_and_moves_years() -> None:
    """Full ``fixlabel`` pipeline should normalise underscores and year placement."""

    assert fixlabel("تصنيف:2020_في_الرياضة_في_تكساس") == "الرياضة في تكساس في 2020"


def test_add_fee_inserts_preposition_for_supported_categories() -> None:
    """``add_fee`` should only insert the preposition for configured categories."""
    data = [
        ("قوائم أفلام حسب البلد أو اللغة 1999", "قوائم أفلام حسب البلد أو اللغة في 1999"),
        ("أحداث حسب القارة 1999", "أحداث حسب القارة في 1999"),
    ]
    for text, expected in data:
        assert add_fee(text) == expected


def test_fix_it_should_not_remove_fe_from_endings() -> None:
    en = "people from santa fe province"
    ar = "أشخاص من محافظة سانتا-في"

    assert fix_it(ar, en) == ar


def test_fix_it_should_not_remove_fe_from_endings2() -> None:
    en = "people from santa fe province by city"
    ar = "أشخاص من محافظة سانتا-في حسب المدينة"

    assert fixlabel(ar, en) == ar



"""
D:/categories_bot/len_data/nationality.py/all_country_ar.json
D:/categories_bot/make2_new/ArWikiCats/jsons/geography/popopo.json


كود بايثون لقراءة الملفين وازالة اي مدخلة موجودة في popopo اذا كانت موجودة في all_country_ar
"""
import json

with open("D:/categories_bot/len_data/nationality.py/all_country_ar.json", "r", encoding="utf-8") as f:
    all_country_ar = json.load(f)

with open("D:/categories_bot/make2_new/ArWikiCats/jsons/geography/popopo.json", "r", encoding="utf-8") as f:
    popopo = json.load(f)

deleted = 0
diff = 0

for key in list(popopo.keys()):
    if key in all_country_ar:
        if all_country_ar[key] != popopo[key]:
            diff += 1
            print(f"Different entry for key '{key}': all_country_ar='{all_country_ar[key]}', popopo='{popopo[key]}'")
        del popopo[key]
        deleted += 1

with open("D:/categories_bot/make2_new/ArWikiCats/jsons/geography/popopo.json", "w", encoding="utf-8") as f:
    json.dump(popopo, f, ensure_ascii=False, indent=4)

print(f"Total deleted entries: {deleted}")
print(f"Total different entries: {diff}")



import functools

from ...helps import logger
from .film_keys_bot import Films, get_Films_key_CAO
from .resolve_films_labels import get_films_key_tyty_new
from .resolve_films_labels_and_time import get_films_key_tyty_new_and_time


@functools.lru_cache(maxsize=None)
def resolve_nationalities_main(normalized_category) -> str:
    """
    Resolve a film nationalities label from a category string.

    Normalizes the input by trimming whitespace, converting to lowercase, and removing a leading "category:" prefix, then queries a sequence of film-label resolvers and returns the first non-empty result.

    Parameters:
        normalized_category (str): Category text to resolve; may include a leading "category:" prefix.

    Returns:
        str: The resolved label if any resolver finds a match, otherwise an empty string.
    """
    normalized_category = normalized_category.strip().lower().replace("category:", "")

    logger.debug("--" * 20)
    logger.debug(f"<><><><><><> <<green>> Trying nationalities_resolvers resolvers for: {normalized_category=}")

    resolved_label = (
        get_films_key_tyty_new_and_time(normalized_category)
        or get_Films_key_CAO(normalized_category)
        or get_films_key_tyty_new(normalized_category)
        or Films(normalized_category)
        or ""
    )

    logger.info_if_or_debug(
        f"<<yellow>> end nationalities_resolvers: {normalized_category=}, {resolved_label=}", resolved_label
    )
    return resolved_label


__all__ = [
    "resolve_nationalities_main",
    "get_films_key_tyty_new",
    "get_films_key_tyty_new_and_time",
]



"""
Tests
"""

import pytest
from load_one_data import dump_diff, dump_same_and_not_same, one_dump_test

from ArWikiCats.new.resolve_films_bots.film_keys_bot import Films
from ArWikiCats.new.resolve_films_bots.resolve_films_labels import get_films_key_tyty_new

fast_data_with_nat0 = {
    "mexican television series-endings": "مسلسلات تلفزيونية مكسيكية انتهت في",
    "austrian television series-endings": "مسلسلات تلفزيونية نمساوية انتهت في",
    "canadian television series-endings": "مسلسلات تلفزيونية كندية انتهت في",
    "chilean television series-endings": "مسلسلات تلفزيونية تشيلية انتهت في",
    "spanish television series-debuts": "مسلسلات تلفزيونية إسبانية بدأ عرضها في",
    "polish television series-debuts": "مسلسلات تلفزيونية بولندية بدأ عرضها في",
    "puerto rican television series-debuts": "مسلسلات تلفزيونية بورتوريكية بدأ عرضها في",
}

fast_data_with_nat = {
    # "american superhero films": "أفلام أبطال خارقين أمريكية",
    "american animated films": "أفلام رسوم متحركة أمريكية",
    "american thriller films": "أفلام إثارة أمريكية",
    "american zombie novels": "روايات زومبي أمريكية",
    "argentine adult animated television series": "مسلسلات تلفزيونية رسوم متحركة للكبار أرجنتينية",
    "australian comedy thriller films": "أفلام كوميدية إثارة أسترالية",
    "australian erotic thriller films": "أفلام إثارة جنسية أسترالية",
    "australian films": "أفلام أسترالية",
    "austrian films": "أفلام نمساوية",
    "austrian silent short films": "أفلام قصيرة صامته نمساوية",
    "azerbaijani short films": "أفلام قصيرة أذربيجانية",
    "bangladeshi films": "أفلام بنغلاديشية",
    "belgian drama films": "أفلام درامية بلجيكية",
    "british films": "أفلام بريطانية",
    "british mystery films": "أفلام غموض بريطانية",
    "british mystery television series": "مسلسلات تلفزيونية غموض بريطانية",
    "british robot films": "أفلام آلية بريطانية",
    "burmese romantic drama films": "أفلام رومانسية درامية بورمية",
    "canadian docudrama films": "أفلام درامية وثائقية كندية",
    "canadian war films": "أفلام حربية كندية",
    "chinese epic films": "أفلام ملحمية صينية",
    "colombian children's animated television series": "مسلسلات تلفزيونية رسوم متحركة أطفال كولومبية",
    "croatian biographical films": "أفلام سير ذاتية كرواتية",
    "croatian fantasy films": "أفلام فانتازيا كرواتية",
    "croatian science fiction films": "أفلام خيال علمي كرواتية",
    "danish adventure television series": "مسلسلات تلفزيونية مغامرات دنماركية",
    "danish black-and-white films": "أفلام أبيض وأسود دنماركية",
    "dutch films": "أفلام هولندية",
    "dutch short films": "أفلام قصيرة هولندية",
    "dutch television-seasons": "مواسم تلفزيونية هولندية",
    "dutch war drama films": "أفلام حربية درامية هولندية",
    "ecuadorian science fiction films": "أفلام خيال علمي إكوادورية",
    "emirati animated films": "أفلام رسوم متحركة إماراتية",
    "french films": "أفلام فرنسية",
    "french musical comedy films": "أفلام كوميدية موسيقية فرنسية",
    "german disaster films": "أفلام كوارثية ألمانية",
    "ghanaian films": "أفلام غانية",
    "indian crime films": "أفلام جريمة هندية",
    "indian dark fantasy films": "أفلام فانتازيا مظلمة هندية",
    "indian sports drama films": "أفلام رياضية درامية هندية",
    "indonesian prequel films": "أفلام بادئة إندونيسية",
    "indonesian zombie films": "أفلام زومبي إندونيسية",
    "iranian romantic drama films": "أفلام رومانسية درامية إيرانية",
    "irish fantasy films": "أفلام فانتازيا أيرلندية",
    "irish films": "أفلام أيرلندية",
    "irish speculative fiction films": "أفلام خيالية تأملية أيرلندية",
    "irish thriller films": "أفلام إثارة أيرلندية",
    "italian comedy films": "أفلام كوميدية إيطالية",
    "italian zombie films": "أفلام زومبي إيطالية",
    "japanese films": "أفلام يابانية",
    "japanese heist films": "أفلام سرقة يابانية",
    "kuwaiti short films": "أفلام قصيرة كويتية",
    "latvian films": "أفلام لاتفية",
    "malaysian sports films": "أفلام رياضية ماليزية",
    "mexican crime thriller films": "أفلام إثارة وجريمة مكسيكية",
    "mexican independent films": "أفلام مستقلة مكسيكية",
    "moroccan musical films": "أفلام موسيقية مغربية",
    "nigerian musical drama films": "أفلام موسيقية درامية نيجيرية",
    "north korean drama films": "أفلام درامية كورية شمالية",
    "norwegian comedy-drama films": "أفلام كوميدية درامية نرويجية",
    "philippine kung fu films": "أفلام كونغ فو فلبينية",
    "polish crime thriller films": "أفلام إثارة وجريمة بولندية",
    "polish epic films": "أفلام ملحمية بولندية",
    "polish television-seasons": "مواسم تلفزيونية بولندية",
    "portuguese adult animated films": "أفلام رسوم متحركة للكبار برتغالية",
    "portuguese fantasy films": "أفلام فانتازيا برتغالية",
    "portuguese musical comedy films": "أفلام كوميدية موسيقية برتغالية",
    "romanian films": "أفلام رومانية",
    "russian sports drama films": "أفلام رياضية درامية روسية",
    "saudiarabian films": "أفلام سعودية",
    "serbian crime television series": "مسلسلات تلفزيونية جريمة صربية",
    "slovenian animated films": "أفلام رسوم متحركة سلوفينية",
    "south korean sequel films": "أفلام متممة كورية جنوبية",
    "soviet drama films": "أفلام درامية سوفيتية",
    "soviet films": "أفلام سوفيتية",
    "soviet short films": "أفلام قصيرة سوفيتية",
    "spanish action films": "أفلام حركة إسبانية",
    "spanish documentary films": "أفلام وثائقية إسبانية",
    "spanish films": "أفلام إسبانية",
    "spanish independent films": "أفلام مستقلة إسبانية",
    "spanish war drama films": "أفلام حربية درامية إسبانية",
    "swedish 3d films": "أفلام ثلاثية الأبعاد سويدية",
    "venezuelan silent short films": "أفلام قصيرة صامته فنزويلية",
}

fast_data_no_nat = {
    "action films": "أفلام حركة",
    "adventure films": "أفلام مغامرات",
    "animated films": "أفلام رسوم متحركة",
    "anime films": "أفلام أنمي",
    "anthology films": "أفلام أنثولوجيا",
    "black comedy films": "أفلام كوميدية سوداء",
    "buddy films": "أفلام رفقاء",
    "comedy films": "أفلام كوميدية",
    "crime films": "أفلام جريمة",
    "dark fantasy films": "أفلام فانتازيا مظلمة",
    "documentary films": "أفلام وثائقية",
    "epic films": "أفلام ملحمية",
    "fantasy films": "أفلام فانتازيا",
    "horror films": "أفلام رعب",
    "mystery film series": "سلاسل أفلام غموض",
    "parody films": "أفلام ساخرة",
    "police procedural films": "أفلام إجراءات الشرطة",
    "science fiction thriller films": "أفلام إثارة خيال علمي",
    "thriller films": "أفلام إثارة",
    "war films": "أفلام حربية",
    "melodrama films": "أفلام ميلودراما",
}


@pytest.mark.parametrize("category, expected", fast_data_no_nat.items(), ids=fast_data_no_nat.keys())
@pytest.mark.fast
def test_resolve_films_no_nat(category: str, expected: str) -> None:
    label = Films(category)
    assert label == expected


to_test = [
    ("no_nat", fast_data_no_nat, Films),
    ("with_nat_tyty", fast_data_with_nat, get_films_key_tyty_new),
    ("no_nat_tyty", fast_data_no_nat, get_films_key_tyty_new),
]


@pytest.mark.parametrize("name,data,callback", to_test)
@pytest.mark.dump
def test_resolve_films_all(name: str, data: dict[str, str], callback) -> None:
    expected, diff_result = one_dump_test(data, callback)

    dump_diff(diff_result, name)
    dump_same_and_not_same(data, diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



# -*- coding: utf-8 -*-
"""Pytest to validate all title lists using fixlabel()."""

from ArWikiCats.fix.fixtitle import fixlabel


def load_test_fixlab_data(data: dict) -> None:
    expected_list = []
    diff_list = []
    same = 0
    for title, expected in data.items():
        result = fixlabel(title)
        # result = result.replace("جرائم قتل", "جرائم قتل في")

        if result != expected:
            diff_list.append({"en": title, "ar": result})
            expected_list.append({"en": title, "ar": expected})
        else:
            assert result == expected
            same += 1

    print(f"<<green>> diff_list: {len(diff_list)}, {same=}.")

    assert diff_list == expected_list


def test_fixlab_group_1() -> None:
    data = {
        "1995 في الإمارات": "الإمارات في 1995",
        "2020 في جنوب إفريقيا": "جنوب إفريقيا في 2020",
        "2020 في مولدوفا": "مولدوفا في 2020",
        "2020 ق م في جنوب إفريقيا": "جنوب إفريقيا في 2020 ق م",
        "الألفية 1 في اليمن": "اليمن في الألفية 1",
        "القرن 20 في مصر": "مصر في القرن 20",
        "القرن 20 ق م في مصر": "مصر في القرن 20 ق م",
        "القرن 21 في الأردن": "الأردن في القرن 21",
        "القرن 21 في جنوب إفريقيا": "جنوب إفريقيا في القرن 21",
        "عقد 1980 ق م في العراق": "العراق في عقد 1980 ق م",
        "عقد 1990 في السعودية": "السعودية في عقد 1990",
        "عقد 2010 في جنوب إفريقيا": "جنوب إفريقيا في عقد 2010",
        "عقد 2010 ق م في جنوب إفريقيا": "جنوب إفريقيا في عقد 2010 ق م",
    }
    load_test_fixlab_data(data)


def test_fixlab_group_2() -> None:
    data = {
        "قضاة حسب الجنسية عقد 2010": "قضاة في عقد 2010 حسب الجنسية",
        "فنانون ذكور حسب الجنسية 2020": "فنانون ذكور في 2020 حسب الجنسية",
        "قضاة حسب الجنسية القرن 20": "قضاة في القرن 20 حسب الجنسية",
        "فنانون ذكور حسب الجنسية القرن 20": "فنانون ذكور في القرن 20 حسب الجنسية",
        "ملكيون حسب البلد القرن 20": "ملكيون في القرن 20 حسب البلد",
    }
    load_test_fixlab_data(data)


def test_fixlab_group_3() -> None:
    data = {
        "أشخاص حسب الجنسية والمجموعة العرقية القرن 20": "أشخاص في القرن 20 حسب الجنسية والمجموعة العرقية",
        "أشخاص حسب الجنسية والمهنة القرن 20": "أشخاص في القرن 20 حسب الجنسية والمهنة",
        "أشخاص حسب الجنسية والمهنة القرن 21": "أشخاص في القرن 21 حسب الجنسية والمهنة",
        "أشخاص حسب الجنسية والمهنة القرن 1 ق م": "أشخاص في القرن 1 ق م حسب الجنسية والمهنة",
        "أشخاص حسب الجنسية والمهنة القرن 2 ق م": "أشخاص في القرن 2 ق م حسب الجنسية والمهنة",
        "أشخاص حسب الجنسية والمهنة القرن 3 ق م": "أشخاص في القرن 3 ق م حسب الجنسية والمهنة",
        "أشخاص حسب الجنسية والمهنة القرن 5 ق م": "أشخاص في القرن 5 ق م حسب الجنسية والمهنة",
        "أشخاص حسب الجنسية والمهنة القرن 1": "أشخاص في القرن 1 حسب الجنسية والمهنة",
        "أشخاص حسب الجنسية والمهنة القرن 2": "أشخاص في القرن 2 حسب الجنسية والمهنة",
        "أشخاص حسب الجنسية والمهنة القرن 3": "أشخاص في القرن 3 حسب الجنسية والمهنة",
        "أشخاص حسب الجنسية والمهنة القرن 5": "أشخاص في القرن 5 حسب الجنسية والمهنة",
    }
    load_test_fixlab_data(data)


def test_fixlab_group_4() -> None:
    data = {
        "أشخاص حسب الدين والجنسية القرن 19": "أشخاص في القرن 19 حسب الدين والجنسية",
        "أشخاص حسب الدين والجنسية القرن 20": "أشخاص في القرن 20 حسب الدين والجنسية",
        "أشخاص حسب المهنة والجنسية القرن 10": "أشخاص في القرن 10 حسب المهنة والجنسية",
        "أشخاص حسب المهنة والجنسية القرن 7": "أشخاص في القرن 7 حسب المهنة والجنسية",
        "أشخاص حسب المهنة والجنسية القرن 8": "أشخاص في القرن 8 حسب المهنة والجنسية",
        "أشخاص حسب المهنة والجنسية القرن 9": "أشخاص في القرن 9 حسب المهنة والجنسية",
        "أشخاص حسب المجموعة العرقية القرن 12": "أشخاص في القرن 12 حسب المجموعة العرقية",
        "أشخاص حسب المجموعة العرقية القرن 21": "أشخاص في القرن 21 حسب المجموعة العرقية",
        "رجال حسب المهنة والجنسية القرن 18": "رجال في القرن 18 حسب المهنة والجنسية",
    }
    load_test_fixlab_data(data)


def test_fixlab_group_5() -> None:
    data = {
        "قوائم أفلام حسب البلد أو اللغة 1930": "قوائم أفلام في 1930 حسب البلد أو اللغة",
        "قوائم أفلام حسب البلد أو اللغة 1931": "قوائم أفلام في 1931 حسب البلد أو اللغة",
        "قوائم أفلام حسب البلد أو اللغة 1932": "قوائم أفلام في 1932 حسب البلد أو اللغة",
        "قوائم أفلام حسب البلد أو اللغة 1933": "قوائم أفلام في 1933 حسب البلد أو اللغة",
        "قوائم أفلام حسب البلد أو اللغة 1935": "قوائم أفلام في 1935 حسب البلد أو اللغة",
        "قوائم أفلام حسب البلد أو اللغة 1936": "قوائم أفلام في 1936 حسب البلد أو اللغة",
        "قوائم أفلام حسب البلد أو اللغة 1950": "قوائم أفلام في 1950 حسب البلد أو اللغة",
    }
    load_test_fixlab_data(data)



#
from .check_it import (
    check_key_in_tables,
    check_key_in_tables_return_tuple,
    get_value_from_any_table,
)
from .fixing import fix_minor
from .match_relation_word import get_relation_word

__all__ = [
    "fix_minor",
    "check_key_in_tables",
    "get_value_from_any_table",
    "check_key_in_tables_return_tuple",
    "get_relation_word",
]



#
import pytest

from ArWikiCats.translations.geo.us_counties import (
    USA_PARTY_LABELS,
    _build_party_derived_keys,
)


@pytest.mark.unit
class TestUSCountiesHelpers:
    def test_build_party_derived_keys_skips_blank_labels(self) -> None:
        derived = _build_party_derived_keys({"Democratic Party": "الحزب الديمقراطي", "Blank Party": " "})

        assert "democratic party" in derived
        assert derived["democratic party members"] == "أعضاء الحزب الديمقراطي"
        assert "blank party" not in derived

    def test_get_party_labels_returns_copy(self) -> None:
        assert USA_PARTY_LABELS["democratic party"] == "الحزب الديمقراطي"



"""
Tests
"""

import pytest

from ArWikiCats.new.end_start_bots.fax2 import (
    get_from_endswith_dict,
    get_from_starts_dict,
    get_list_of_and_cat3,
    to_get_endswith,
    to_get_startswith,
)


@pytest.mark.fast
def test_get_from_starts_dict() -> None:
    # Test with a basic input that starts with a known key
    category3, list_of_cat = get_from_starts_dict("21st century members of test", to_get_startswith)
    assert isinstance(category3, str)
    assert isinstance(list_of_cat, str)

    # Test with empty string
    category3_empty, list_of_cat_empty = get_from_starts_dict("", to_get_startswith)
    assert isinstance(category3_empty, str)
    assert isinstance(list_of_cat_empty, str)


@pytest.mark.fast
def test_get_from_endswith_dict() -> None:
    # Test with a basic input that ends with a known key
    category3, list_of_cat = get_from_endswith_dict("test squad navigational boxes", to_get_endswith)
    assert isinstance(category3, str)
    assert isinstance(list_of_cat, str)

    # Test with empty string
    category3_empty, list_of_cat_empty = get_from_endswith_dict("", to_get_endswith)
    assert isinstance(category3_empty, str)
    assert isinstance(list_of_cat_empty, str)


@pytest.mark.fast
def test_get_list_of_and_cat3() -> None:
    # Test with a basic input
    list_of_cat, foot_ballers, category3 = get_list_of_and_cat3("test category", "Test Category")
    assert isinstance(list_of_cat, str)
    assert isinstance(foot_ballers, bool)
    assert isinstance(category3, str)

    # Test with episodes
    list_of_cat22, foot_ballers2, category3_2 = get_list_of_and_cat3("test episodes", "Test Episodes")
    assert isinstance(foot_ballers2, bool)
    assert isinstance(category3_2, str)

    # Test with empty strings
    list_of_cat_empty, foot_ballers_empty, category3_empty = get_list_of_and_cat3("", "")
    assert isinstance(list_of_cat_empty, str)
    assert isinstance(foot_ballers_empty, bool)
    assert isinstance(category3_empty, str)



""" """

from typing import Dict, Tuple

dict_temps: Dict[str, str] = {
    "templates": "قوالب {}",
    "squad templates": "قوالب تشكيلات {}",
}

sorted_data = dict(
    sorted(
        dict_temps.items(),
        key=lambda k: (-k[0].count(" "), -len(k[0])),
    )
)


def get_templates_fo(category3: str) -> Tuple[str, str]:
    """
    Examples:
        category3="Category:2016 American television infobox templates"
    """
    category3 = category3.strip()
    list_of_cat = ""

    for key, lab in sorted_data.items():
        if category3.endswith(key):
            list_of_cat = lab
            # remove the key ONLY from the end
            category3 = category3[: -len(key)].strip()
            return list_of_cat, category3

    return "", category3



#
import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats import resolve_arabic_category_label

data1 = {
    "animation directors": "x",
    "anti-corruption activists": "x",
    "antiquarians": "x",
    "arts administrators": "x",
    "astrological writers": "x",
    "auctioneers": "x",
    "bacteriologists": "x",
    "ballerinas": "x",
    "ballet masters": "x",
    "balloonists": "x",
    "bank robbers": "x",
    "baritones": "x",
    "barristers": "x",
    "bass-baritones": "x",
    "biomechanists": "x",
    "blacksmiths": "x",
    "booksellers": "x",
    "border guards": "x",
    "botanical writers": "x",
    "bricklayers": "x",
    "brothel owners": "x",
    "bryologists": "x",
    "business theorists": "x",
    "cabinetmakers": "x",
    "candlepin bowling players": "x",
    "car collectors": "x",
    "carpenters": "x",
    "chairmeof corporations": "x",
    "chaplains": "x",
    "chess writers": "x",
    "chief technologists": "x",
    "chief technology officers": "x",
    "children's book illustrators": "x",
    "chiropractors": "x",
    "chroniclers": "x",
    "city founders": "x",
    "civil engineering contractors": "x",
    "clarinetists": "x",
    "classical clarinetists": "x",
    "classical organists": "x",
    "classical viola d'amore players": "x",
    "classical violists": "x",
    "comedy duos": "x",
    "congregationalist ministers": "x",
    "contract bridge players": "x",
    "cosmonauts": "x",
    "courtesans": "x",
    "craftspeople": "x",
    "duckpin bowling players": "x",
    "ecclesiastical architects": "x",
    "electricians": "x",
    "engineering academics": "x",
    "erotic dancers": "x",
    "erotic photographers": "x",
    "eskrimadors": "x",
    "exercise instructors": "x",
    "financial analysts": "x",
    "five-pin bowling players": "x",
    "folk harpists": "x",
    "folk-song collectors": "x",
    "foreign policy writers": "x",
    "foresters": "x",
    "game show hosts": "x",
    "gangsters": "x",
    "garden writers": "x",
    "genealogists": "x",
    "general practitioners": "x",
    "geochemists": "x",
    "geomorphologists": "x",
    "hammered dulcimer players": "x",
    "harmonicists": "x",
    "harpists": "x",
    "harpsichordists": "x",
    "hedge fund managers": "x",
    "hokkien pop singers": "x",
    "ian dissidents": "x",
    "indologists": "x",
    "infotainers": "x",
    "innovators": "x",
    "investment bankers": "x",
    "jazz accordionists": "x",
    "jazz clarinetists": "x",
    "jazz double-bassists": "x",
    "jazz horn players": "x",
    "jazz tubists": "x",
    "jazz upright-bassists": "x",
    "jazz vibraphonists": "x",
    "jewellers": "x",
    "labor unionists": "x",
    "ladies-in-waiting": "x",
    "latinists": "x",
    "latter day saint writers": "x",
    "letter writers": "x",
    "lichenologists": "x",
    "limnologists": "x",
    "lobbyists": "x",
    "magazine people": "x",
    "magistrates": "x",
    "mandolin players": "x",
    "materials scientists": "x",
    "media personalities": "x",
    "media scholars": "x",
    "medical administrators": "x",
    "mesoamerican": "x",
    "metallurgists": "x",
    "mezzo-sopranos": "x",
    "military chaplains": "x",
    "missionarys": "x",
    "mobsters": "x",
    "museologists": "x",
    "musical instrument makers": "x",
    "musical theatre lyricists": "x",
    "musical theatre": "x",
    "mycologists": "x",
    "naïve painters": "x",
    "netballers": "x",
    "nine-pin bowling players": "x",
    "numismatists": "x",
    "nurserymen": "x",
    "nursing administrators": "x",
    "occult writers": "x",
    "operatic basses": "x",
    "operatic mezzo-sopranos": "x",
    "operatic sopranos": "x",
    "optometrists": "x",
    "orchardists": "x",
    "orienteers": "x",
    "orthodox rabbis": "x",
    "oud players": "x",
    "outlaws": "x",
    "palaeographers": "x",
    "palaeontologists": "x",
    "paleoanthropologists": "x",
    "paleogeographers": "x",
    "papyrologists": "x",
    "paraglider pilots": "x",
    "pastoralists": "x",
    "people irail transport": "x",
    "philatelists": "x",
    "phytopathologists": "x",
    "pipe organ builders": "x",
    "planktologists": "x",
    "plumbers": "x",
    "podcasters": "x",
    "police chiefs": "x",
    "pool players": "x",
    "prosecutors": "x",
    "psychologists": "x",
    "public relations people": "x",
    "public servants": "x",
    "punk rock groups": "x",
    "ranchers": "x",
    "rapists": "x",
    "reporters and correspondents": "x",
    "roboticists": "x",
    "roman catholic clergy": "x",
    "self-help writers": "x",
    "semioticians": "x",
    "sex offenders": "x",
    "sex workers": "x",
    "shamans": "x",
    "silent actors": "x",
    "silversmiths": "x",
    "social commentators": "x",
    "song collectors": "x",
    "speleologists": "x",
    "spiritual mediums": "x",
    "spree killers": "x",
    "stained glass artists and manufacturers": "x",
    "stockbrokers": "x",
    "stonemasons": "x",
    "storytellers": "x",
    "stunt performers": "x",
    "suffragists": "x",
    "talent agents": "x",
    "telenovela actors": "x",
    "television evangelists": "x",
    "temperance activists": "x",
    "ten-pibowling players": "x",
    "ten-pin bowling players": "x",
    "tenors": "x",
    "textbook writers": "x",
    "theatre architects": "x",
    "theatre critics": "x",
    "tin whistle players": "x",
    "topographers": "x",
    "uilleann pipers": "x",
    "vedettes": "x",
    "veterinary scientists": "x",
    "vibraphonists": "x",
    "viola d'amore players": "x",
    "violists": "x",
    "watchmakers (people)": "x",
    "web series actresses": "x",
    "wicket-keeper": "x",
    "wicket-keepers": "x",
    "writers on paranormal topics": "x",
}


TEMPORAL_CASES = [
    ("test_Jobs_22_empty", data1),
]


@pytest.mark.parametrize("name,data", TEMPORAL_CASES)
@pytest.mark.skip2
def test_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



# -*- coding: utf-8 -*-

from .games_labs import SUMMER_WINTER_GAMES
from .Sport_key import SPORTS_KEYS_FOR_JOBS, SPORTS_KEYS_FOR_LABEL, SPORTS_KEYS_FOR_TEAM
from .tennis import TENNIS_KEYS

__all__ = [
    "TENNIS_KEYS",
    "SUMMER_WINTER_GAMES",
    "SPORTS_KEYS_FOR_TEAM",
    "SPORTS_KEYS_FOR_LABEL",
    "SPORTS_KEYS_FOR_JOBS",
]



"""
Tests
"""

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.legacy_bots.ma_bots2.ar_lab_bot import find_ar_label

simple_list = [
    ("1550 mass shootings in oceania", " in ", "إطلاق نار عشوائي 1550 في أوقيانوسيا"),
    ("mass shootings in oceania", " in ", "إطلاق نار عشوائي في أوقيانوسيا"),
    ("1550 elections in sweden", " in ", "انتخابات 1550 في السويد"),
    ("argentine people of american descent", " of ", "أرجنتينيون في أصل أمريكي"),
    ("bermudian people of world-war-ii", " of ", "برموديون في الحرب العالمية الثانية"),
    ("1550s in rugby union", " in ", "عقد 1550 في اتحاد الرجبي"),
    ("1550 in sarawak", " in ", "1550 في ساراواك"),
    ("montserratian expatriates in england", " in ", "مونتسراتيون مغتربون في إنجلترا"),
]


@pytest.mark.parametrize("category, separator, output", simple_list, ids=[x[0] for x in simple_list])
@pytest.mark.fast
def test_simple(category: str, separator: str, output: str) -> None:
    label = find_ar_label(category, separator, use_event2=False)
    assert label == output


mass_media_list = [
    ("mass media in bosnia and herzegovina by medium", " by ", "وسائل الإعلام في البوسنة والهرسك حسب الوسط"),
    ("mass media in bosnia and herzegovina", " in ", "وسائل الإعلام في البوسنة والهرسك"),
    ("1550 in mass media", " in ", "1550 في وسائل إعلام"),
    ("sports mass media in united arab emirates", " in ", "إعلام ألعاب رياضية في الإمارات العربية المتحدة"),
    ("defunct mass media in new jersey", " in ", "وسائل إعلام سابقة في نيوجيرسي"),
]

data_list = [
    (" university of annaba", " of ", "جامعة عنابة"),
    ("1550 by city", " by ", "1550 حسب المدينة"),
    ("1550 by country", " by ", "1550 حسب البلد"),
    ("1550 disestablishments by continent", " by ", "انحلالات سنة 1550 حسب القارة"),
    ("1550 disestablishments by country", " by ", "انحلالات سنة 1550 حسب البلد"),
    ("1550 elections by country", " by ", "انتخابات 1550 حسب البلد"),
    ("1550 establishments by continent", " by ", "تأسيسات سنة 1550 حسب القارة"),
    ("1550 establishments by country", " by ", "تأسيسات سنة 1550 حسب البلد"),
    ("1550 in antigua and barbuda by month", " by ", "أنتيغوا وباربودا في 1550 حسب الشهر"),
    ("1550 in mexico by month", " by ", "المكسيك في 1550 حسب الشهر"),
    ("1550 in south america by month", " by ", "أمريكا الجنوبية في 1550 حسب الشهر"),
    ("1550 in sports by country", " by ", "ألعاب رياضية في 1550 حسب البلد"),
    ("1550 in thailand by month", " by ", "تايلاند في 1550 حسب الشهر"),
    ("1550 in women's sport by country", " by ", "رياضة نسائية في 1550 حسب البلد"),
    ("1550 in-sports-in alberta", " in-sports-in ", "1550 في الرياضة في ألبرتا"),
    ("1550 in-sports-in arizona", " in-sports-in ", "1550 في الرياضة في أريزونا"),
    ("1550 in-sports-in british columbia", " in-sports-in ", "1550 في الرياضة في كولومبيا البريطانية"),
    ("1550 in-sports-in mississippi", " in-sports-in ", "1550 في الرياضة في مسيسيبي"),
    ("1550 in-sports-in nebraska", " in-sports-in ", "1550 في الرياضة في نبراسكا"),
    ("1550 in-sports-in new york (state)", " in-sports-in ", "1550 في الرياضة في ولاية نيويورك"),
    ("1550 in-sports-in ohio", " in-sports-in ", "1550 في الرياضة في أوهايو"),
    ("1550s in asia by city", " by ", "آسيا في عقد 1550 حسب المدينة"),
    ("20th century in iraq by city", " by ", "العراق في القرن 20 حسب المدينة"),
    ("academics from tuscany", " from ", "أكاديميون من توسكانا"),
    ("actresses from ohio by county", " by ", "ممثلات من أوهايو حسب المقاطعة"),
    ("actresses from ohio", " from ", "ممثلات من أوهايو"),
    ("acts of parliament of ireland 1550", " of ", "أفعال برلمان أيرلندا 1550"),
    ("african games gold medalists for chad", " for ", "فائزون بميداليات ذهبية في الألعاب الإفريقية من تشاد"),
    ("algerian companies established in 1550", " established in ", "شركات جزائرية أسست في 1550"),
    ("ambassadors of austria to canada", " to ", "سفراء النمسا لدى كندا"),
    ("ambassadors of austria", " of ", "سفراء النمسا"),
    ("ambassadors of brazil to netherlands", " to ", "سفراء البرازيل لدى هولندا"),
    ("ambassadors of brazil", " of ", "سفراء البرازيل"),
    ("ambassadors of canada to peru", " to ", "سفراء كندا لدى بيرو"),
    ("ambassadors of canada", " of ", "سفراء كندا"),
    ("ambassadors of chad to russia", " to ", "سفراء تشاد لدى روسيا"),
    ("ambassadors of chad", " of ", "سفراء تشاد"),
    ("ambassadors of china to guinea-bissau", " to ", "سفراء الصين لدى غينيا بيساو"),
    ("ambassadors of china", " of ", "سفراء الصين"),
    ("ambassadors of fiji to japan", " to ", "سفراء فيجي لدى اليابان"),
    ("ambassadors of fiji", " of ", "سفراء فيجي"),
    ("ambassadors of ghana to colombia", " to ", "سفراء غانا لدى كولومبيا"),
    ("ambassadors of ghana", " of ", "سفراء غانا"),
    ("ambassadors of great britain to ottoman empire", " to ", "سفراء بريطانيا العظمى لدى الدولة العثمانية"),
    ("ambassadors of great britain", " of ", "سفراء بريطانيا العظمى"),
    ("ambassadors of italy to chile", " to ", "سفراء إيطاليا لدى تشيلي"),
    ("ambassadors of italy", " of ", "سفراء إيطاليا"),
    ("ambassadors of japan to saudi arabia", " to ", "سفراء اليابان لدى السعودية"),
    ("ambassadors of japan", " of ", "سفراء اليابان"),
    ("ambassadors of palau to japan", " to ", "سفراء بالاو لدى اليابان"),
    ("ambassadors of palau", " of ", "سفراء بالاو"),
    ("ambassadors to guinea-bissau", " to ", "سفراء إلى غينيا بيساو"),
    ("ambassadors to south sudan", " to ", "سفراء إلى جنوب السودان"),
    ("amusement park attractions introduced in 1550", " introduced in ", "متنزهات ملاهي جاذبة عرضت في 1550"),
    ("animated films about mammals", " about ", "أفلام رسوم متحركة عن ثدييات"),
    ("antigua and barbuda by month", " by ", "أنتيغوا وباربودا حسب الشهر"),
    ("april 1550 by country", " by ", "أبريل 1550 حسب البلد"),
    ("argentine people of american descent", " of ", "أرجنتينيون في أصل أمريكي"),
    ("armenian people of ukrainian descent", " of ", "أرمن في أصل أوكراني"),
    ("artists from novi sad", " from ", "فنانون من نوفي ساد"),
    ("artists from zurich", " from ", "فنانون من زيورخ"),
    ("asia by city", " by ", "آسيا حسب المدينة"),
    ("august 1550 by continent", " by ", "أغسطس 1550 حسب القارة"),
    ("august 1550 by country", " by ", "أغسطس 1550 حسب البلد"),
    ("austrian artists by century", " by ", "فنانون نمساويون حسب القرن"),
    ("azerbaijani emigrants to united kingdom", " to ", "أذربيجانيون مهاجرون إلى المملكة المتحدة"),
    ("bahraini emigrants to united states", " to ", "بحرينيون مهاجرون إلى الولايات المتحدة"),
    ("bahraini people of ethiopian descent", " of ", "بحرينيون في أصل إثيوبي"),
    ("banks based in tennessee", " based in ", "بنوك مقرها في تينيسي"),
    ("baseball playerss in florida by team", " by ", "لاعبو كرة قاعدة في فلوريدا حسب الفريق"),
    ("baseball playerss in south korea by team", " by ", "لاعبو كرة قاعدة في كوريا الجنوبية حسب الفريق"),
    ("bermudian people of world-war-ii", " of ", "برموديون في الحرب العالمية الثانية"),
    ("biologists from xinjiang", " from ", "علماء أحياء من سنجان"),
    ("biota of libya", " of ", "حيويات ليبيا"),
    ("black metal albums by french artists", " by ", "ألبومات بلاك ميتال حسب بواسطة فنانون فرنسيون"),
    ("blues musicians from tennessee", " from ", "موسيقيو بلوز من تينيسي"),
    ("bolivian artists by century", " by ", "فنانون بوليفيون حسب القرن"),
    ("bridges in france by material", " by ", "جسور في فرنسا حسب المادة"),
    ("cabinets of british columbia ", " of ", "مجالس وزراء في كولومبيا البريطانية"),
    ("cabinets of british columbia navigational boxes", " of ", "مجالس وزراء في صناديق تصفح كولومبيا البريطانية"),
    ("cantons of marseille", " of ", "كانتونات مارسيليا"),
    ("chemical companies established in 1550", " established in ", "شركات كيميائية أسست في 1550"),
    ("christians from ohio", " from ", "مسيحيون من أوهايو"),
    ("churches completed in 1550", " completed in ", "كنائس اكتملت في 1550"),
    ("city of zagreb", " of ", "مدينة زغرب"),
    ("civilians killed in wars", " killed in ", "مدنيون قتلوا في حروب"),
    ("clergy from poznań", " from ", "رجال دين من بوزنان"),
    ("clubhouses on the-national-register-of-historic-places", " on ", "نوادي في السجل الوطني للأماكن التاريخية"),
    ("clubs and societies of university of sheffield", " of ", "أندية وجمعيات في جامعة شفيلد"),
    ("comedy by medium", " by ", "كوميديا حسب الوسط"),
    ("comic strips by date", " by ", "شرائط كومكس حسب التاريخ"),
    ("comics images from india", " from ", "صور قصص مصورة من الهند"),
    ("communes of saïda province", " of ", "بلديات ولاية سعيدة"),
    ("companies by former country", " by ", "شركات حسب البلد السابق"),
    ("companies of cambodia", " of ", "شركات في كمبوديا"),
    ("constituencies disestablished in 1550", " disestablished in ", "دوائر إنتخابية انحلت في 1550"),
    ("constituencies of parliament of barbados", " of ", "دوائر إنتخابية في برلمان بربادوس"),
    ("constitutions of british overseas territories", " of ", "دساتير في أقاليم ما وراء البحار البريطانية"),
    ("courthouses on the-national-register-of-historic-places", " on ", "محاكم في السجل الوطني للأماكن التاريخية"),
    ("crimes in peru by year", " by ", "جرائم في بيرو حسب السنة"),
    ("crustaceans described in 1550", " described in ", "قشريات وصفت في 1550"),
    ("cultural organizations based in portugal", " based in ", "منظمات ثقافية مقرها في البرتغال"),
    ("culture of maharashtra", " of ", "ثقافة ماهاراشترا"),
    ("defunct airlines of paraguay", " of ", "شركات طيران سابقة في باراغواي"),
    ("defunct learned societies of united kingdom", " of ", "جمعيات علمية سابقة في المملكة المتحدة"),
    ("disestablishments in ecuador by decade", " by ", "انحلالات في الإكوادور حسب العقد"),
    ("disestablishments in yugoslavia by year", " by ", "انحلالات في يوغسلافيا حسب السنة"),
    ("districts of taipei", " of ", "مديريات تايبيه"),
    ("dog breeds originating in japan", " originating in ", "سلالات كلاب نشأت في اليابان"),
    ("donkey breeds originating in portugal", " originating in ", "سلالات حمير نشأت في البرتغال"),
    ("dutch companies established in 1550", " established in ", "شركات هولندية أسست في 1550"),
    ("dutch people of hungarian descent", " of ", "هولنديون في أصل مجري"),
    ("echinoderms described in 20th century", " described in ", "شوكيات الجلد وصفت في القرن 20"),
    ("economy of burundi", " of ", "اقتصاد بوروندي"),
    ("economy of kwazulu-natal", " of ", "اقتصاد كوازولو ناتال"),
    ("economy of renfrewshire", " of ", "اقتصاد رينفروشاير"),
    ("ecuador by decade", " by ", "الإكوادور حسب العقد"),
    ("ecuadorian television series-endings by decade", " by ", "مسلسلات تلفزيونية إكوادورية انتهت في حسب العقد"),
    ("educators from meghalaya", " from ", "معلمون من ميغالايا"),
    ("emirati people of tunisian descent", " of ", "إماراتيون في أصل تونسي"),
    ("energy companies established in 1550", " established in ", "شركات طاقة أسست في 1550"),
    ("environment of essex", " of ", "بيئة إسكس"),
    ("establishments in guernsey by decade", " by ", "تأسيسات في غيرنزي حسب العقد"),
    ("ethiopian people of armenian descent", " of ", "إثيوبيون في أصل أرميني"),
    ("european football by country", " by ", "كرة القدم الأوروبية حسب البلد"),
    ("fauna of vermont", " of ", "حيوانات فيرمونت"),
    ("fiction set in 1550", " set in ", "الخيال تقع أحداثها في 1550"),
    ("films about royal air force", " about ", "أفلام عن القوات الجوية الملكية"),
    ("films basedon works", " basedon ", "أفلام مبنية على أعمال"),
    ("films by japanese directors", " by ", "أفلام حسب بواسطة مخرجون يابانيون"),
    ("films set in 1550s", " set in ", "أفلام تقع أحداثها في عقد 1550"),
    ("films set in copenhagen", " set in ", "أفلام تقع أحداثها في كوبنهاغن"),
    ("films shot in islamabad", " shot in ", "أفلام مصورة في إسلام آباد"),
    ("films shot in united states by city", " shot in ", "أفلام مصورة في الولايات المتحدة حسب المدينة"),
    ("films with screenplays by emma thompson", " with screenplays by ", "أفلام كتب نصها السينمائي إيما تومسون"),
    ("financial services companies of seychelles", " of ", "شركات خدمات مالية في سيشل"),
    ("first ladies of rwanda", " of ", "السيدات الأولى في رواندا"),
    ("fishes of europe", " of ", "أسماك أوروبا"),
    ("flags of connecticut", " of ", "أعلام كونيتيكت"),
    ("flags of vatican city", " of ", "أعلام الفاتيكان"),
    ("flora of estonia", " of ", "نباتات إستونيا"),
    ("food and drink companies of botswana", " of ", "شركات أطعمة ومشروبات في بوتسوانا"),
    ("football clubs established in 1550", " established in ", "أندية كرة قدم أسست في 1550"),
    ("footballers from harlow", " from ", "لاعبو كرة قدم من هارلو"),
    ("footballers from mexico city", " from ", "لاعبو كرة قدم من مدينة مكسيكو"),
    ("french companies disestablished in 1550", " disestablished in ", "شركات فرنسية انحلت في 1550"),
    ("geography of kansas by populated place", " by ", "جغرافيا كانساس حسب المكان المأهول"),
    ("geography of kansas", " of ", "جغرافيا كانساس"),
    ("ghanaian people of nigerien descent", " of ", "غانيون في أصل نيجري"),
    ("government ministers of northern cyprus", " of ", "وزراء قبرص الشمالية"),
    ("government of chicago", " of ", "حكومة شيكاغو"),
    ("government of la rioja", " of ", "حكومة منطقة لا ريوخا"),
    ("government of moldova", " of ", "حكومة مولدوفا"),
    ("government of nazi germany", " of ", "حكومة ألمانيا النازية"),
    ("grand viziers of egypt", " of ", "صدور عظام في مصر"),
    ("greenlandic emigrants to canada", " to ", "جرينلانديون مهاجرون إلى كندا"),
    ("guatemalan people by religion", " by ", "غواتيماليون حسب الدين"),
    ("guernsey by decade", " by ", "غيرنزي حسب العقد"),
    ("hard rock albums by south korean artists", " by ", "ألبومات هارد روك حسب بواسطة فنانون كوريون جنوبيون"),
    ("heads of universities and colleges", " of ", "قادة جامعات وكليات"),
    (
        "high schools in india by state or union territory",
        " by ",
        "مدارس ثانوية في الهند حسب الولاية أو الإقليم الاتحادي",
    ),
    ("history books about islam", " about ", "كتب تاريخ عن الإسلام"),
    ("history of copenhagen by topic", " by ", "تاريخ كوبنهاغن حسب الموضوع"),
    ("history of copenhagen", " of ", "تاريخ كوبنهاغن"),
    ("history of craiova", " of ", "تاريخ كرايوفا"),
    ("holding companies established in 1550", " established in ", "شركات قابضة أسست في 1550"),
    ("horse races established in 1550", " established in ", "سباقات الخيل أسست في 1550"),
    ("hospital buildings completed in 20th century", " completed in ", "مباني مستشفيات اكتملت في القرن 20"),
    ("hotel buildings completed in 1550", " completed in ", "مبان فنادق اكتملت في 1550"),
    ("indian companies established in 1550", " established in ", "شركات هندية أسست في 1550"),
    ("industrial parks by country", " by ", "متنزهات صناعية حسب البلد"),
    ("infrastructure completed in 1550", " completed in ", "بنية تحتية اكتملت في 1550"),
    ("international gymnastics competitions hosted by germany", " hosted by ", "منافسات جمباز دولية استضافتها ألمانيا"),
    ("introductions by time", " by ", "استحداثات حسب الوقت"),
    ("iraq by city", " by ", "العراق حسب المدينة"),
    ("irish people by religion", " by ", "أيرلنديون حسب الدين"),
    ("islamic organizations based in bangladesh", " based in ", "منظمات إسلامية مقرها في بنغلاديش"),
    ("jewish organizations established in 1550", " established in ", "منظمات يهودية أسست في 1550"),
    ("july 1550 by country", " by ", "يوليو 1550 حسب البلد"),
    ("june 1550 by continent", " by ", "يونيو 1550 حسب القارة"),
    ("landforms of michigan", " of ", "تضاريس ميشيغان"),
    ("languages of gilgit-baltistan", " of ", "لغات غلغت-بلتستان"),
    ("laws regarding rape", " regarding ", "قوانين عن الاغتصاب"),
    ("lawyers from new orleans", " from ", "محامون من نيو أورلينز"),
    ("liberian sport by decade", " by ", "رياضة ليبيرية حسب العقد"),
    ("lists of ambassadors to south sudan", " to ", "قوائم سفراء إلى جنوب السودان"),
    ("lists of ambassadors", " of ", "قوائم سفراء"),
    ("lists of buildings and structures", " of ", "قوائم مبان ومنشآت"),
    ("lists of faroese politicians", " of ", "قوائم سياسيون فارويون"),
    ("lists of fauna of vermont", " of ", "قوائم حيوانات فيرمونت"),
    ("lists of fishes of europe", " of ", "قوائم أسماك أوروبا"),
    ("lists of legislators", " of ", "قوائم مشرعون"),
    ("lists of mayors of places", " of ", "قوائم رؤساء بلديات"),
    ("lists of organizations by dependent territory", " by ", "منظمات قوائم حسب الأقاليم التابعة"),
    ("lists of roads", " of ", "قوائم طرقات"),
    ("literary characters introduced in 1550", " introduced in ", "شخصيات أدبية عرضت في 1550"),
    ("local politicians in united kingdom by party", " by ", "سياسيون محليون في المملكة المتحدة حسب الحزب"),
    ("magazines published in tennessee", " published in ", "مجلات نشرت في تينيسي"),
    ("malaysian people by populated place", " by ", "ماليزيون حسب المكان المأهول"),
    ("male actors from lubusz voivodeship", " from ", "ممثلون ذكور من محافظة لوبوسكي"),
    ("male voice actors from kanagawa prefecture", " from ", "ممثلو أداء صوتي ذكور من محافظة كاناغاوا"),
    ("manufacturing companies based in michigan", " based in ", "شركات تصنيع مقرها في ميشيغان"),
    ("manufacturing companies established in 1550", " established in ", "شركات تصنيع أسست في 1550"),
    ("may 1550 by continent", " by ", "مايو 1550 حسب القارة"),
    ("mayors of ajaccio", " of ", "عمدات أجاكسيو"),
    ("members of maine legislature", " of ", "أعضاء هيئة مين التشريعية"),
    ("men's footballers in togo by club", " by ", "لاعبو كرة قدم في توغو حسب النادي"),
    ("mexico by month", " by ", "المكسيك حسب الشهر"),
    ("military campaigns involving denmark", " involving ", "حملات عسكرية تشمل الدنمارك"),
    (
        "military facilities on the-national-register-of-historic-places",
        " on ",
        "مرافق عسكرية في السجل الوطني للأماكن التاريخية",
    ),
    ("military installations established in 1550s", " established in ", "منشآت عسكرية أسست في عقد 1550"),
    ("military of second bulgarian empire", " of ", "عسكرية الإمبراطورية البلغارية الثانية"),
    (
        "military operations involving soviet union by war",
        " involving ",
        "عمليات عسكرية تشمل الاتحاد السوفيتي حسب الحرب",
    ),
    ("military operations of american civil war", " of ", "عمليات عسكرية في الحرب الأهلية الأمريكية"),
    ("military personnel from ross and cromarty", " from ", "أفراد عسكريون من روس وكرومارتي"),
    (
        "military units and formations disestablished in 1550",
        " disestablished in ",
        "وحدات وتشكيلات عسكرية انحلت في 1550",
    ),
    ("mine warfare vessels of united states navy", " of ", "سفن حرب ألغام في البحرية الأمريكية"),
    ("models from essex", " from ", "عارضو أزياء من إسكس"),
    ("monarchs by country", " by ", "ملكيون حسب البلد"),
    ("mountain ranges of alaska", " of ", "سلاسل جبلية في ألاسكا"),
    ("municipalities of greenland", " of ", "بلديات جرينلاند"),
    ("museums disestablished in 1550", " disestablished in ", "متاحف انحلت في 1550"),
    ("musicals set in barcelona", " set in ", "مسرحيات غنائية تقع أحداثها في برشلونة"),
    ("mystery films by language", " by ", "أفلام غموض حسب اللغة"),
    ("newspaper people by newspaper in california", " by ", "شخصيات صحف حسب الصحيفة في كاليفورنيا"),
    ("nigerian people of hungarian descent", " of ", "نيجيريون في أصل مجري"),
    ("norwegian drummers by century", " by ", "طبالون نرويجيون حسب القرن"),
    ("novels by continent of setting", " by ", "روايات حسب قارة الأحداث"),
    ("october 1550 by country", " by ", "أكتوبر 1550 حسب البلد"),
    ("olympic boxers for aruba", " for ", "ملاكمون أولمبيون في أروبا"),
    ("olympic footballers for south korea", " for ", "لاعبو كرة قدم أولمبيون في كوريا الجنوبية"),
    ("olympic judoka by year", " by ", "لاعبو جودو أولمبيون حسب السنة"),
    ("olympic lugers for estonia", " for ", "زاحفون ثلجيون أولمبيون في إستونيا"),
    ("olympic shooters for iceland", " for ", "رماة أولمبيون في آيسلندا"),
    ("olympic silver medalists for finland", " for ", "فائزون بميداليات فضية أولمبية من فنلندا"),
    ("olympic skeleton racers for italy", " for ", "متزلجون صدريون أولمبيون في إيطاليا"),
    ("olympic speed skaters for lithuania", " for ", "متزلجو سرعة أولمبيون في ليتوانيا"),
    ("omani expatriate sports-people by country-of-residence", " by ", "رياضيون عمانيون مغتربون حسب بلد الإقامة"),
    ("opera houses on the-national-register-of-historic-places", " on ", "دور أوبرا في السجل الوطني للأماكن التاريخية"),
    ("organizations based in paris", " based in ", "منظمات مقرها في باريس"),
    ("organizations based in western sahara by subject", " based in ", "منظمات مقرها في الصحراء الغربية حسب الموضوع"),
    ("organizations by dependent territory", " by ", "منظمات حسب الأقاليم التابعة"),
    ("paintings of queen victoria", " of ", "لوحات عن الملكة فيكتوريا"),
    ("pakistani companies established in 1550", " established in ", "شركات باكستانية أسست في 1550"),
    ("paralympic competitors for cyprus", " for ", "منافسون بارالمبيون من قبرص"),
    (
        "paralympic wheelchair curlers by year",
        " by ",
        "لاعبو كيرلنغ على الكراسي المتحركة في الألعاب البارالمبية حسب السنة",
    ),
    ("parliament of barbados", " of ", "برلمان بربادوس"),
    ("parliament of ireland 1550", " of ", "برلمان أيرلندا 1550"),
    ("people from al-andalus", " from ", "أشخاص من الأندلس"),
    ("people from al-hasakah governorate", " from ", "أشخاص من محافظة الحسكة"),
    ("people from almaty", " from ", "أشخاص من ألماتي"),
    ("people from bangkok by occupation", " by ", "أشخاص من بانكوك حسب المهنة"),
    ("people from bangkok", " from ", "أشخاص من بانكوك"),
    ("people from batangas by occupation", " by ", "أشخاص من باتانغاس حسب المهنة"),
    ("people from batangas", " from ", "أشخاص من باتانغاس"),
    ("people from brokopondo district", " from ", "أشخاص من ضاحية بروكوبوندو"),
    ("people from burhanpur", " from ", "أشخاص من برهانبور"),
    (
        "people from east lothian by populated place and occupation",
        " by ",
        "أشخاص من لوثيان الشرقية حسب المكان المأهول والمهنة",
    ),
    ("people from east lothian", " from ", "أشخاص من لوثيان الشرقية"),
    ("people from falkenberg", " from ", "أشخاص من فالكنبرغ"),
    ("people from leudal", " from ", "أشخاص من لودال"),
    ("people from parbhani", " from ", "أشخاص من باربهاني"),
    ("people from rimavská sobota", " from ", "أشخاص من ريمافسكا سوبوتا"),
    ("people from rivne oblast", " from ", "أشخاص من ريفنا أوبلاست"),
    ("people from rohtak", " from ", "أشخاص من روهتاك"),
    ("people from taiz", " from ", "أشخاص من تعز"),
    ("people from vyborg", " from ", "أشخاص من فيبورغ"),
    ("people from whanganui", " from ", "أشخاص من وانجانوي"),
    ("people murdered in 1550", " murdered in ", "أشخاص قتلوا في 1550"),
    ("peru by year", " by ", "بيرو حسب السنة"),
    ("peruvian people by occupation and century", " by ", "بيرويون حسب المهنة والقرن"),
    ("pharmaceutical companies of taiwan", " of ", "شركات أدوية في تايوان"),
    ("political organizations based in barbados", " based in ", "منظمات سياسية مقرها في بربادوس"),
    (
        "political organizations based in oceania by country",
        " based in ",
        "منظمات سياسية مقرها في أوقيانوسيا حسب البلد",
    ),
    ("politics of bhagalpur district", " of ", "سياسة مقاطعة بهاغالبور"),
    ("politics of second polish republic", " of ", "سياسة الجمهورية البولندية الثانية"),
    (
        "populated places disestablished in 20th century bc",
        " disestablished in ",
        "أماكن مأهولة انحلت في القرن 20 ق م",
    ),
    ("populated places established in 1550", " established in ", "أماكن مأهولة أسست في 1550"),
    ("presidency of jose p. laurel", " of ", "رئاسة خوسي لوريل"),
    ("prime ministers of japan", " of ", "رؤساء وزراء اليابان"),
    ("prime ministers of ukraine", " of ", "رؤساء وزراء أوكرانيا"),
    ("prisoners and detainees of liechtenstein", " of ", "سجناء ومعتقلون في ليختنشتاين"),
    ("publications disestablished in 20th century", " disestablished in ", "منشورات انحلت في القرن 20"),
    ("publications established in 1550", " established in ", "منشورات أسست في 1550"),
    ("publications established in 1550s", " established in ", "منشورات أسست في عقد 1550"),
    ("radio stations disestablished in 1550", " disestablished in ", "محطات إذاعية انحلت في 1550"),
    ("railway stations in canada closed in 1550", " closed in ", "محطات السكك الحديدية في كندا أغلقت في 1550"),
    ("railway stations in japan opened in 1550", " opened in ", "محطات السكك الحديدية في اليابان افتتحت في 1550"),
    (
        "railway stations in netherlands opened in 1550",
        " opened in ",
        "محطات السكك الحديدية في هولندا افتتحت في 1550",
    ),
    (
        "railway stations in new zealand closed in 1550",
        " closed in ",
        "محطات السكك الحديدية في نيوزيلندا أغلقت في 1550",
    ),
    (
        "railway stations in north korea opened in 1550",
        " opened in ",
        "محطات السكك الحديدية في كوريا الشمالية افتتحت في 1550",
    ),
    ("railway stations in russia opened in 1550", " opened in ", "محطات السكك الحديدية في روسيا افتتحت في 1550"),
    (
        "railway stations in united kingdom closed in 1550",
        " closed in ",
        "محطات السكك الحديدية في المملكة المتحدة أغلقت في 1550",
    ),
    (
        "railway stations in united states closed in 1550",
        " closed in ",
        "محطات السكك الحديدية في الولايات المتحدة أغلقت في 1550",
    ),
    ("railway stations opened in 1550s", " opened in ", "محطات السكك الحديدية افتتحت في عقد 1550"),
    ("recurring events established in 1550", " established in ", "أحداث دورية أسست في 1550"),
    ("religion in united states by region", " by ", "الدين في الولايات المتحدة حسب المنطقة"),
    ("religious buildings and structures completed in 1550", " completed in ", "مبان ومنشآت دينية اكتملت في 1550"),
    ("religious buildings and structures completed in 1550s", " completed in ", "مبان ومنشآت دينية اكتملت في عقد 1550"),
    ("religious festivals by type", " by ", "مهرجانات دينية حسب الفئة"),
    ("religious organizations based in iceland", " based in ", "منظمات دينية مقرها في آيسلندا"),
    ("religious organizations established in 1550", " established in ", "منظمات دينية أسست في 1550"),
    ("renewable energy companies of myanmar", " of ", "شركات طاقة متجددة في ميانمار"),
    ("reptiles described in 1550", " described in ", "زواحف وصفت في 1550"),
    ("restaurants established in 1550", " established in ", "مطاعم أسست في 1550"),
    ("rivers of perlis", " of ", "أنهار برليس"),
    ("rivers of qinghai", " of ", "أنهار تشينغهاي"),
    ("rivers of wales", " of ", "أنهار ويلز"),
    ("rugby league players from oldham", " from ", "لاعبو دوري رجبي من أولدهام"),
    ("rugby union players from utah", " from ", "لاعبو اتحاد رجبي من يوتا"),
    (
        "saint kitts and nevis in summer olympics by year",
        " by ",
        "سانت كيتس ونيفيس في الألعاب الأولمبية الصيفية حسب السنة",
    ),
    ("scientists from indianapolis", " from ", "علماء من إنديانابوليس"),
    ("secretaries-of state of nevada", " of ", "وزراء خارجية نيفادا"),
    ("shopping malls in ukraine by populated place", " by ", "مراكز تسوق في أوكرانيا حسب المكان المأهول"),
    ("singers from zacatecas", " from ", "مغنون من ولاية زاكاتيكاس"),
    ("ska albums by artist nationality", " by ", "ألبومات سكا حسب جنسية الفنان"),
    ("slovenian people by period", " by ", "سلوفينيون حسب الحقبة"),
    ("social workers from delhi", " from ", "أخصائيون اجتماعيون من دلهي"),
    ("songs about invertebrates", " about ", "أغاني عن لافقاريات"),
    ("south african mathematicians by century", " by ", "رياضياتيون جنوب إفريقيون حسب القرن"),
    ("south america by month", " by ", "أمريكا الجنوبية حسب الشهر"),
    ("spiders described in 1550", " described in ", "عناكب وصفت في 1550"),
    ("sport by continent", " by ", "رياضة حسب القارة"),
    ("sport in ottoman empire by year", " by ", "الرياضة في الدولة العثمانية حسب السنة"),
    ("sports clubs and teams disestablished in 1550", " disestablished in ", "أندية وفرق رياضية انحلت في 1550"),
    ("sports coaches from illinois", " from ", "مدربو رياضة من إلينوي"),
    ("sports coaches from oregon", " from ", "مدربو رياضة من أوريغن"),
    ("sports organizations by continent", " by ", "منظمات رياضية حسب القارة"),
    ("sports originating in pakistan", " originating in ", "ألعاب رياضية نشأت في باكستان"),
    ("sports venues by type", " by ", "ملاعب رياضية حسب الفئة"),
    ("sports-people from central kalimantan", " from ", "رياضيون من كالمنتان الوسطى"),
    ("sports-people from florina", " from ", "رياضيون من فلورينا"),
    ("sports-people from getxo", " from ", "رياضيون من غوتكسو"),
    ("sports-people from temuco", " from ", "رياضيون من تيموكو"),
    ("sports-people from tukums", " from ", "رياضيون من توكومز"),
    ("sports-people in ireland by club or team", " by ", "رياضيون في أيرلندا حسب النادي أو الفريق"),
    ("sportswomen from new south wales", " from ", "رياضيات من نيوساوث ويلز"),
    ("states and territories disestablished in 1550", " disestablished in ", "دول وأقاليم انحلت في 1550"),
    ("states and territories established in 1550", " established in ", "دول وأقاليم أسست في 1550"),
    ("sudanese people of hungarian descent", " of ", "سودانيون في أصل مجري"),
    ("suicides by-firearm-in nevada", " by-firearm-in ", "منتحرون بإطلاق النار في نيفادا"),
    ("summer olympics competitors for peru", " for ", "منافسون أولمبيون صيفيون من بيرو"),
    ("swedish emigrants to jordan", " to ", "سويديون مهاجرون إلى الأردن"),
    ("swedish male musicians by century", " by ", "موسيقيون ذكور سويديون حسب القرن"),
    ("symbols of nuevo león", " of ", "رموز ولاية نويفو ليون"),
    ("synagogues completed in 1550", " completed in ", "كنس اكتملت في 1550"),
    ("television channels and stations established in 1550", " established in ", "قنوات وشبكات تلفزيونية أسست في 1550"),
    ("thailand by month", " by ", "تايلاند حسب الشهر"),
    ("theatre by country", " by ", "المسرح حسب البلد"),
    ("tourism in united kingdom by city", " by ", "سياحة في المملكة المتحدة حسب المدينة"),
    ("towers completed in 1550", " completed in ", "أبراج اكتملت في 1550"),
    ("trade associations based in quebec", " based in ", "اتحادات تجارية مقرها في كيبك"),
    ("trade unionists from missouri", " from ", "نقابيون من ميزوري"),
    ("transport organizations based in bahamas", " based in ", "منظمات نقل مقرها في باهاماس"),
    ("transport organizations based in norway", " based in ", "منظمات نقل مقرها في النرويج"),
    ("turkish people of georgian descent", " of ", "أتراك في أصل جورجي"),
    (
        "united nations security council resolutions concerning angola",
        " concerning ",
        "قرارات مجلس الأمن التابع للأمم المتحدة بشأن أنغولا",
    ),
    (
        "united nations security council resolutions concerning turkmenistan",
        " concerning ",
        "قرارات مجلس الأمن التابع للأمم المتحدة بشأن تركمانستان",
    ),
    ("university of annaba", " of ", "جامعة عنابة"),
    ("university of sheffield", " of ", "جامعة شفيلد"),
    ("uzbekistani emigrants to australia", " to ", "أوزبكستانيون مهاجرون إلى أستراليا"),
    ("victims of aviation accidents or incidents", " of ", "ضحايا حوادث طيران"),
    ("video game franchises introduced in 1550", " introduced in ", "امتيازات ألعاب فيديو عرضت في 1550"),
    ("villages in north macedonia by municipality", " by ", "قرى في مقدونيا الشمالية حسب البلدية"),
    ("wars involving nepal", " involving ", "حروب تشمل نيبال"),
    ("water of novosibirsk oblast", " of ", "مياه في نوفوسيبيرسك أوبلاست"),
    ("welsh people of singaporean descent", " of ", "ويلزيون في أصل سنغافوري"),
    ("wikipedia categories named after israeli musicians", " named after ", "تصنيفات سميت بأسماء موسيقيون إسرائيليون"),
    ("women politicians by century", " by ", "سياسيات حسب القرن"),
    ("women's sport by country", " by ", "رياضة نسائية حسب البلد"),
    ("works about alberta", " about ", "أعمال عن ألبرتا"),
    ("works by austrian filmmakers", " by ", "أعمال حسب بواسطة صانعو أفلام نمساويون"),
    ("works set in guinea-bissau", " set in ", "أعمال تقع أحداثها في غينيا بيساو"),
    ("writers from abruzzo", " from ", "كتاب من أبروتسو"),
    ("writers from al-andalus", " from ", "كتاب من الأندلس"),
    ("writers from celje", " from ", "كتاب من تسليه"),
    ("writers from german empire", " from ", "كتاب من الإمبراطورية الألمانية"),
    ("years of 20th century", " of ", "سنوات القرن 20"),
    ("youth organizations based in montserrat", " based in ", "منظمات شبابية مقرها في مونتسرات"),
    ("yugoslavia by year", " by ", "يوغسلافيا حسب السنة"),
    ("zoologists from austrian empire", " from ", "علماء حيوانات من الإمبراطورية النمساوية"),
]

data_list_in = {
    "1550 in belgian motorsport": "1550 في رياضة المحركات البلجيكية",
    "1550 in chinese motorsport": "1550 في رياضة المحركات الصينية",
    "1550 in english cricket": "1550 في الكريكت الإنجليزية",
    "1550 in french tennis": "1550 في كرة المضرب الفرنسية",
    "1550 in indian tennis": "1550 في كرة المضرب الهندية",
    "1550 in japanese football leagues": "1550 في دوريات كرة القدم اليابانية",
    "1550 in south american football leagues": "1550 في دوريات كرة القدم الأمريكية الجنوبية",
    "1550 in spanish tennis": "1550 في كرة المضرب الإسبانية",
    "1550 in swedish football leagues": "1550 في دوريات كرة القدم السويدية",
    "nordic skiing competitions in slovakia": "منافسات التزلج النوردية في سلوفاكيا",
    "railway stations in dordogne": "محطات السكك الحديدية في دوردونيي (إقليم فرنسي)",
    "seasons in asian football leagues": "مواسم في دوريات كرة القدم الآسيوية",
    "sport in álava": "الرياضة في ألافا (مقاطعة)",
    "1550 awards in united states": "جوائز 1550 في الولايات المتحدة",
    "1550 crimes in brazil": "جرائم 1550 في البرازيل",
    "1550 crimes in israel": "جرائم 1550 في إسرائيل",
    "1550 crimes in madagascar": "جرائم 1550 في مدغشقر",
    "1550 crimes in oceania": "جرائم 1550 في أوقيانوسيا",
    "1550 disasters in australia": "كوارث 1550 في أستراليا",
    "1550 disasters in kenya": "كوارث 1550 في كينيا",
    "1550 disasters in mexico": "كوارث 1550 في المكسيك",
    "1550 disasters in oceania": "كوارث 1550 في أوقيانوسيا",
    "1550 disestablishments in afghanistan": "انحلالات سنة 1550 في أفغانستان",
    "1550 disestablishments in alabama": "انحلالات سنة 1550 في ألاباما",
    "1550 disestablishments in alaska": "انحلالات سنة 1550 في ألاسكا",
    "1550 disestablishments in asia": "انحلالات سنة 1550 في آسيا",
    "1550 disestablishments in belgium": "انحلالات سنة 1550 في بلجيكا",
    "1550 disestablishments in cyprus": "انحلالات سنة 1550 في قبرص",
    "1550 disestablishments in denmark": "انحلالات سنة 1550 في الدنمارك",
    "1550 disestablishments in europe": "انحلالات سنة 1550 في أوروبا",
    "1550 disestablishments in hungary": "انحلالات سنة 1550 في المجر",
    "1550 disestablishments in indiana": "انحلالات سنة 1550 في إنديانا",
    "1550 disestablishments in new york (state)": "انحلالات سنة 1550 في ولاية نيويورك",
    "1550 disestablishments in north america": "انحلالات سنة 1550 في أمريكا الشمالية",
    "1550 disestablishments in philippines": "انحلالات سنة 1550 في الفلبين",
    "1550 disestablishments in portugal": "انحلالات سنة 1550 في البرتغال",
    "1550 disestablishments in quebec": "انحلالات سنة 1550 في كيبك",
    "1550 disestablishments in scotland": "انحلالات سنة 1550 في إسكتلندا",
    "1550 disestablishments in serbia": "انحلالات سنة 1550 في صربيا",
    "1550 elections in croatia": "انتخابات 1550 في كرواتيا",
    "1550 elections in sweden": "انتخابات 1550 في السويد",
    "1550 establishments in andhra pradesh": "تأسيسات سنة 1550 في أندرا برديش",
    "1550 establishments in armenia": "تأسيسات سنة 1550 في أرمينيا",
    "1550 establishments in asia": "تأسيسات سنة 1550 في آسيا",
    "1550 establishments in bahamas": "تأسيسات سنة 1550 في باهاماس",
    "1550 establishments in barbados": "تأسيسات سنة 1550 في بربادوس",
    "1550 establishments in botswana": "تأسيسات سنة 1550 في بوتسوانا",
    "1550 establishments in british overseas territories": "تأسيسات سنة 1550 في أقاليم ما وراء البحار البريطانية",
    "1550 establishments in connecticut": "تأسيسات سنة 1550 في كونيتيكت",
    "1550 establishments in egypt": "تأسيسات سنة 1550 في مصر",
    "1550 establishments in england": "تأسيسات سنة 1550 في إنجلترا",
    "1550 establishments in europe": "تأسيسات سنة 1550 في أوروبا",
    "1550 establishments in france": "تأسيسات سنة 1550 في فرنسا",
    "1550 establishments in gambia": "تأسيسات سنة 1550 في غامبيا",
    "1550 establishments in gujarat": "تأسيسات سنة 1550 في غوجارات",
    "1550 establishments in hawaii": "تأسيسات سنة 1550 في هاواي",
    "1550 establishments in holy roman empire": "تأسيسات سنة 1550 في الإمبراطورية الرومانية المقدسة",
    "1550 establishments in hong kong": "تأسيسات سنة 1550 في هونغ كونغ",
    "1550 establishments in idaho": "تأسيسات سنة 1550 في أيداهو",
    "1550 establishments in ireland": "تأسيسات سنة 1550 في أيرلندا",
    "1550 establishments in kazakh soviet socialist republic": "تأسيسات سنة 1550 في كازاخستان السوفيتية",
    "1550 establishments in kentucky": "تأسيسات سنة 1550 في كنتاكي",
    "1550 establishments in lebanon": "تأسيسات سنة 1550 في لبنان",
    "1550 establishments in malaysia": "تأسيسات سنة 1550 في ماليزيا",
    "1550 establishments in malta": "تأسيسات سنة 1550 في مالطا",
    "1550 establishments in maryland": "تأسيسات سنة 1550 في ماريلند",
    "1550 establishments in mozambique": "تأسيسات سنة 1550 في موزمبيق",
    "1550 establishments in namibia": "تأسيسات سنة 1550 في ناميبيا",
    "1550 establishments in nepal": "تأسيسات سنة 1550 في نيبال",
    "1550 establishments in new jersey": "تأسيسات سنة 1550 في نيوجيرسي",
    "1550 establishments in new zealand": "تأسيسات سنة 1550 في نيوزيلندا",
    "1550 establishments in north carolina": "تأسيسات سنة 1550 في كارولاينا الشمالية",
    "1550 establishments in north dakota": "تأسيسات سنة 1550 في داكوتا الشمالية",
    "1550 establishments in north yemen": "تأسيسات سنة 1550 في اليمن الشمالي",
    "1550 establishments in oklahoma": "تأسيسات سنة 1550 في أوكلاهوما",
    "1550 establishments in philippines": "تأسيسات سنة 1550 في الفلبين",
    "1550 establishments in rhode island": "تأسيسات سنة 1550 في رود آيلاند",
    "1550 establishments in russia": "تأسيسات سنة 1550 في روسيا",
    "1550 establishments in singapore": "تأسيسات سنة 1550 في سنغافورة",
    "1550 establishments in south america": "تأسيسات سنة 1550 في أمريكا الجنوبية",
    "1550 establishments in south carolina": "تأسيسات سنة 1550 في كارولاينا الجنوبية",
    "1550 establishments in south dakota": "تأسيسات سنة 1550 في داكوتا الجنوبية",
    "1550 establishments in spain": "تأسيسات سنة 1550 في إسبانيا",
    "1550 establishments in spanish empire": "تأسيسات سنة 1550 في الإمبراطورية الإسبانية",
    "1550 establishments in sweden": "تأسيسات سنة 1550 في السويد",
    "1550 establishments in switzerland": "تأسيسات سنة 1550 في سويسرا",
    "1550 establishments in thirteen colonies": "تأسيسات سنة 1550 في المستعمرات الثلاث عشرة",
    "1550 establishments in uruguay": "تأسيسات سنة 1550 في أوروغواي",
    "1550 establishments in virginia": "تأسيسات سنة 1550 في فرجينيا",
    "1550 establishments in wales": "تأسيسات سنة 1550 في ويلز",
    "1550 establishments in wyoming": "تأسيسات سنة 1550 في وايومنغ",
    "1550 establishments in yugoslavia": "تأسيسات سنة 1550 في يوغسلافيا",
    "1550 in alabama": "1550 في ألاباما",
    "1550 in antarctica": "1550 في القارة القطبية الجنوبية",
    "1550 in antigua and barbuda": "1550 في أنتيغوا وباربودا",
    "1550 in archery": "1550 في النبالة",
    "1550 in australia": "1550 في أستراليا",
    "1550 in bermuda": "1550 في برمودا",
    "1550 in biotechnology": "1550 في تقانة حيوية",
    "1550 in brazilian sport": "1550 في رياضة برازيلية",
    "1550 in british columbia": "1550 في كولومبيا البريطانية",
    "1550 in british empire": "1550 في الإمبراطورية البريطانية",
    "1550 in british music": "1550 في موسيقى بريطانية",
    "1550 in bulgaria": "1550 في بلغاريا",
    "1550 in burmese sport": "1550 في رياضة بورمية",
    "1550 in cameroonian football": "1550 في كرة القدم الكاميرونية",
    "1550 in china": "1550 في الصين",
    "1550 in christianity": "1550 في المسيحية",
    "1550 in comics": "1550 في قصص مصورة",
    "1550 in danish television": "1550 في التلفزة الدنماركية",
    "1550 in delaware": "1550 في ديلاوير",
    "1550 in djibouti": "1550 في جيبوتي",
    "1550 in dominican republic": "1550 في جمهورية الدومينيكان",
    "1550 in economic history": "1550 في التاريخ الاقتصادي",
    "1550 in education": "1550 في تعليم",
    "1550 in europe": "1550 في أوروبا",
    "1550 in fencing": "1550 في مبارزة سيف الشيش",
    "1550 in field hockey": "1550 في هوكي الميدان",
    "1550 in finland": "1550 في فنلندا",
    "1550 in formula racing": "1550 في سباقات فورمولا",
    "1550 in french colonial empire": "1550 في الإمبراطورية الاستعمارية الفرنسية",
    "1550 in french television": "1550 في التلفزة الفرنسية",
    "1550 in georgia (u.s. state)": "1550 في ولاية جورجيا",
    "1550 in guam": "1550 في غوام",
    "1550 in guangzhou": "1550 في غوانزو",
    "1550 in habsburg monarchy": "1550 في ملكية هابسبورغ",
    "1550 in haiti": "1550 في هايتي",
    "1550 in holy roman empire": "1550 في الإمبراطورية الرومانية المقدسة",
    "1550 in horse racing": "1550 في سباق الخيل",
    "1550 in hungary": "1550 في المجر",
    "1550 in hurling": "1550 في القذف",
    "1550 in illinois": "1550 في إلينوي",
    "1550 in international sports": "1550 في رياضية دولية",
    "1550 in iraq": "1550 في العراق",
    "1550 in iraqi sport": "1550 في رياضة عراقية",
    "1550 in irish women's sport": "1550 في رياضة أيرلندية نسائية",
    "1550 in italian sport": "1550 في رياضة إيطالية",
    "1550 in ivory coast": "1550 في ساحل العاج",
    "1550 in khyber pakhtunkhwa": "1550 في خيبر بختونخوا",
    "1550 in law": "1550 في قانون",
    "1550 in liberia": "1550 في ليبيريا",
    "1550 in libyan sport": "1550 في رياضة ليبية",
    "1550 in lithuania": "1550 في ليتوانيا",
    "1550 in macau": "1550 في ماكاو",
    "1550 in maryland": "1550 في ماريلند",
    "1550 in mexican television": "1550 في التلفزة المكسيكية",
    "1550 in mexico": "1550 في المكسيك",
    "1550 in military history": "1550 في التاريخ العسكري",
    "1550 in minnesota": "1550 في منيسوتا",
    "1550 in missouri": "1550 في ميزوري",
    "1550 in mongolia": "1550 في منغوليا",
    "1550 in motorsport": "1550 في رياضة محركات",
    "1550 in music": "1550 في الموسيقى",
    "1550 in new jersey": "1550 في نيوجيرسي",
    "1550 in new zealand": "1550 في نيوزيلندا",
    "1550 in nordic combined": "1550 في التزلج النوردي المزدوج",
    "1550 in north america": "1550 في أمريكا الشمالية",
    "1550 in north macedonia": "1550 في مقدونيا الشمالية",
    "1550 in norwegian music": "1550 في موسيقى نرويجية",
    "1550 in oregon": "1550 في أوريغن",
    "1550 in outer space": "1550 في الفضاء الخارجي",
    "1550 in philippine cinema": "1550 في السينما الفلبينية",
    "1550 in professional wrestling": "1550 في مصارعة المحترفين",
    "1550 in puerto rico": "1550 في بورتوريكو",
    "1550 in religion": "1550 في الدين",
    "1550 in road cycling": "1550 في سباق الدراجات على الطريق",
    "1550 in romania": "1550 في رومانيا",
    "1550 in san marino": "1550 في سان مارينو",
    "1550 in sarawak": "1550 في ساراواك",
    "1550 in saudi arabia": "1550 في السعودية",
    "1550 in science": "1550 في العلم",
    "1550 in scotland": "1550 في إسكتلندا",
    "1550 in scottish women's sport": "1550 في رياضة إسكتلندية نسائية",
    "1550 in senegalese sport": "1550 في رياضة سنغالية",
    "1550 in serbia": "1550 في صربيا",
    "1550 in sint maarten": "1550 في سينت مارتن",
    "1550 in skeleton": "1550 في الزلاجات الصدرية",
    "1550 in somalian sport": "1550 في رياضة صومالية",
    "1550 in south america": "1550 في أمريكا الجنوبية",
    "1550 in spain": "1550 في إسبانيا",
    "1550 in spanish empire": "1550 في الإمبراطورية الإسبانية",
    "1550 in speed skating": "1550 في التزلج السريع",
    "1550 in syria": "1550 في سوريا",
    "1550 in taiwan": "1550 في تايوان",
    "1550 in taiwanese television": "1550 في التلفزة التايوانية",
    "1550 in tanzania": "1550 في تنزانيا",
    "1550 in thailand": "1550 في تايلاند",
    "1550 in toronto": "1550 في تورونتو",
    "1550 in united arab emirates": "1550 في الإمارات العربية المتحدة",
    "1550 in united nations": "1550 في الأمم المتحدة",
    "1550 in uruguayan football": "1550 في كرة القدم الأوروغويانية",
    "1550 in uzbekistani football": "1550 في كرة القدم الأوزبكستانية",
    "1550 in uzbekistani sport": "1550 في رياضة أوزبكستانية",
    "1550 in vanuatu": "1550 في فانواتو",
    "1550 in venezuela": "1550 في فنزويلا",
    "1550 in virginia": "1550 في فرجينيا",
    "1550 in washington (state)": "1550 في ولاية واشنطن",
    "1550 in west germany": "1550 في ألمانيا الغربية",
    "1550 in women's sport": "1550 في رياضة نسائية",
    "1550 mass shootings in africa": "إطلاق نار عشوائي 1550 في إفريقيا",
    "1550 mass shootings in oceania": "إطلاق نار عشوائي 1550 في أوقيانوسيا",
    "1550 murders in north america": "جرائم قتل في 1550 في أمريكا الشمالية",
    "1550 murders in russia": "جرائم قتل في 1550 في روسيا",
    "1550 natural disasters in united states": "كوارث طبيعية في 1550 في الولايات المتحدة",
    "1550s elections in caribbean": "انتخابات عقد 1550 في الكاريبي",
    "1550s in asia": "عقد 1550 في آسيا",
    "1550s in belgium": "عقد 1550 في بلجيكا",
    "1550s in cycle racing": "عقد 1550 في سباق دراجات",
    "1550s in dundee": "عقد 1550 في دندي",
    "1550s in edmonton": "عقد 1550 في إدمونتون",
    "1550s in england": "عقد 1550 في إنجلترا",
    "1550s in estonia": "عقد 1550 في إستونيا",
    "1550s in hangzhou": "عقد 1550 في هانغتشو",
    "1550s in ice hockey": "عقد 1550 في هوكي الجليد",
    "1550s in japan": "عقد 1550 في اليابان",
    "1550s in literature": "عقد 1550 في أدب",
    "1550s in louisiana": "عقد 1550 في لويزيانا",
    "1550s in maltese sport": "عقد 1550 في رياضة مالطية",
    "1550s in north american sport": "عقد 1550 في رياضة أمريكية شمالية",
    "1550s in politics": "عقد 1550 في سياسة",
    "1550s in portugal": "عقد 1550 في البرتغال",
    "1550s in prince edward island": "عقد 1550 في جزيرة الأمير إدوارد",
    "1550s in quebec": "عقد 1550 في كيبك",
    "1550s in rugby union": "عقد 1550 في اتحاد الرجبي",
    "1550s in russia": "عقد 1550 في روسيا",
    "1550s in saudi arabia": "عقد 1550 في السعودية",
    "1550s in science": "عقد 1550 في العلم",
    "1550s in somaliland": "عقد 1550 في أرض الصومال",
    "1550s in south korean women's sport": "عقد 1550 في رياضة كورية جنوبية نسائية",
    "1550s in technology": "عقد 1550 في التقانة",
    "1550s in track cycling": "عقد 1550 في سباق الدراجات على المضمار",
    "1550s in ukrainian sport": "عقد 1550 في رياضة أوكرانية",
    "1550s in venezuela": "عقد 1550 في فنزويلا",
    "1550s in vietnam": "عقد 1550 في فيتنام",
    "1550s in winter sports": "عقد 1550 في الرياضة الشتوية",
    "20th century in iraq": "القرن 20 في العراق",
    "20th century in kent": "القرن 20 في كنت",
    "20th century in prince edward island": "القرن 20 في جزيرة الأمير إدوارد",
    "20th century in prussia": "القرن 20 في بروسيا",
    "20th century in quetta": "القرن 20 في كويته",
    "2nd millennium in kentucky": "الألفية 2 في كنتاكي",
    "3rd millennium in ghana": "الألفية 3 في غانا",
    "airports in jalisco": "مطارات في ولاية خاليسكو",
    "american expatriate sports-people in qatar": "رياضيون أمريكيون مغتربون في قطر",
    "american expatriates in gambia": "أمريكيون مغتربون في غامبيا",
    "amusement parks in greece": "متنزهات ملاهي في اليونان",
    "amusement parks in maine": "متنزهات ملاهي في مين",
    "anglicanism in tanzania": "أنجليكية في تنزانيا",
    "april 1550 in europe": "أبريل 1550 في أوروبا",
    "april 1550 in oceania": "أبريل 1550 في أوقيانوسيا",
    "april 1550 in russia": "أبريل 1550 في روسيا",
    "april 1550 in united kingdom": "أبريل 1550 في المملكة المتحدة",
    "armenian diaspora in united states": "شتات أرميني في الولايات المتحدة",
    "armenian expatriates in lithuania": "أرمن مغتربون في ليتوانيا",
    "arts festivals in scotland": "مهرجانات فنية في إسكتلندا",
    "astronomical observatories in indiana": "مراصد فلكية في إنديانا",
    "athletics competitions in el salvador": "منافسات ألعاب قوى في السلفادور",
    "august 1550 in north america": "أغسطس 1550 في أمريكا الشمالية",
    "auto racing series in china": "سلسة سباق سيارات في الصين",
    "aviation in minnesota": "طيران في منيسوتا",
    "baseball playerss in florida": "لاعبو كرة قاعدة في فلوريدا",
    "baseball playerss in south korea": "لاعبو كرة قاعدة في كوريا الجنوبية",
    "basketball competitions in ireland": "منافسات كرة سلة في أيرلندا",
    "basketball competitions in north macedonia": "منافسات كرة سلة في مقدونيا الشمالية",
    "basketball in syria": "كرة السلة في سوريا",
    "basketball leagues in oceania": "دوريات كرة السلة في أوقيانوسيا",
    "basketball teams in senegal": "فرق كرة السلة في السنغال",
    "basketball venues in serbia": "ملاعب كرة سلة في صربيا",
    "belarusian expatriate sports-people in austria": "رياضيون بيلاروسيون مغتربون في النمسا",
    "beninese expatriates in sweden": "بنينيون مغتربون في السويد",
    "bissau-guinean expatriates in hungary": "غينيون بيساويون مغتربون في المجر",
    "bowling in asia": "بولينج في آسيا",
    "boxing in australia": "البوكسينغ في أستراليا",
    "bridges in france": "جسور في فرنسا",
    "british expatriate sports-people in antigua and barbuda": "رياضيون بريطانيون مغتربون في أنتيغوا وباربودا",
    "buildings and structures in california": "مبان ومنشآت في كاليفورنيا",
    "buildings and structures in mato grosso do sul": "مبان ومنشآت في ماتو غروسو دو سول",
    "buildings and structures in prostějov": "مبان ومنشآت في بروستيوف",
    "buildings and structures in raichur district": "مبان ومنشآت في مقاطعة رايشور",
    "buildings and structures in vellore district": "مبان ومنشآت في مقاطعة فلور",
    "bulgaria in fiction": "بلغاريا في الخيال",
    "by newspaper in california": "حسب الصحيفة في كاليفورنيا",
    "by university or college in poland": "حسب الجامعة أو الكلية في بولندا",
    "cameroonian expatriate sports-people in egypt": "رياضيون كاميرونيون مغتربون في مصر",
    "cape verdean expatriate sports-people in chile": "رياضيون أخضريون مغتربون في تشيلي",
    "cape verdean expatriates in czech republic": "أخضريون مغتربون في التشيك",
    "castles in hesse": "قلاع في هسن",
    "chess in latvia": "الشطرنج في لاتفيا",
    "child welfare in bangladesh": "رعاية الطفل في بنغلاديش",
    "chinese restaurants in canada": "مطاعم صينية في كندا",
    "christian clergy in ukraine": "رجال دين مسيحيون في أوكرانيا",
    "christian schools in kerala": "مدارس مسيحية في كيرلا",
    "churches in ethiopia": "كنائس في إثيوبيا",
    "churches in marshall islands": "كنائس في جزر مارشال",
    "churches in nigeria": "كنائس في نيجيريا",
    "cities and towns in gandhinagar district": "مدن وبلدات في مقاطعة غانديناغار",
    "clock towers in africa": "أبراج ساعة في إفريقيا",
    "clubhouses on the-national-register-of-historic-places in maine": "نوادي في السجل الوطني للأماكن التاريخية في مين",
    "communes in bié province": "بلديات في مقاطعة بيي",
    "communism in oman": "شيوعية في سلطنة عمان",
    "conspiracy theories in lebanon": "نظريات مؤامرة في لبنان",
    "courthouses in france": "محاكم في فرنسا",
    "courthouses on the-national-register-of-historic-places in illinois": "محاكم في السجل الوطني للأماكن التاريخية في إلينوي",
    "courthouses on the-national-register-of-historic-places in maryland": "محاكم في السجل الوطني للأماكن التاريخية في ماريلند",
    "courthouses on the-national-register-of-historic-places in new york city": "محاكم في السجل الوطني للأماكن التاريخية في مدينة نيويورك",
    "covid-19 pandemic in hawaii": "جائحة فيروس كورونا في هاواي",
    "crimes in peru": "جرائم في بيرو",
    "culture in lugano": "ثقافة في لوغانو",
    "cycling events in australia": "أحداث سباق دراجات هوائية في أستراليا",
    "death in byzantine empire": "الموت في الإمبراطورية البيزنطية",
    "deaths from pneumonia in oklahoma": "وفيات الالتهاب الرئوي في أوكلاهوما",
    "deaths in british virgin islands": "وفيات في جزر العذراء البريطانية",
    "decades in antwerp": "عقود في أنتفيرب",
    "decades in malaysia": "عقود في ماليزيا",
    "december 1550 in asia": "ديسمبر 1550 في آسيا",
    "december 1550 in netherlands": "ديسمبر 1550 في هولندا",
    "december 1550 in thailand": "ديسمبر 1550 في تايلاند",
    "december 1550 in united states": "ديسمبر 1550 في الولايات المتحدة",
    "defunct museums in arkansas": "متاحف سابقة في أركنساس",
    "diasporas in australia": "شتات في أستراليا",
    "disease outbreaks in peru": "تفشي طبي في بيرو",
    "disease-related deaths in zimbabwe": "وفيات مرتبطة بالمرض في زيمبابوي",
    "disestablishments in ecuador": "انحلالات في الإكوادور",
    "disestablishments in yugoslavia": "انحلالات في يوغسلافيا",
    "education in caloocan": "تعليم في كالوكان",
    "elections in united states virgin islands": "انتخابات في جزر العذراء الأمريكية",
    "elementary schools in calgary": "مدارس إبتدائية في كالغاري",
    "energy in cameroon": "طاقة في الكاميرون",
    "entertainment venues in wisconsin": "أماكن ترفيه في ويسكونسن",
    "eritrean expatriates in sweden": "إريتريون مغتربون في السويد",
    "establishments in guernsey": "تأسيسات في غيرنزي",
    "expatriate baseball playerss in canada": "لاعبو كرة قاعدة مغتربون في كندا",
    "expatriate football managers in cook islands": "مدربو كرة قدم مغتربون في جزر كوك",
    "expatriate football managers in northern mariana islands": "مدربو كرة قدم مغتربون في جزر ماريانا الشمالية",
    "february 1550 in austria": "فبراير 1550 في النمسا",
    "february 1550 in india": "فبراير 1550 في الهند",
    "february 1550 in iran": "فبراير 1550 في إيران",
    "february 1550 in philippines": "فبراير 1550 في الفلبين",
    "february 1550 in united states": "فبراير 1550 في الولايات المتحدة",
    "ferry transport in indonesia": "النقل بالعبارات في إندونيسيا",
    "festivals in athens": "مهرجانات في أثينا",
    "festivals in buenos aires": "مهرجانات في بوينس آيرس",
    "food and drink in japan": "أطعمة ومشروبات في اليابان",
    "food and drink in scotland": "أطعمة ومشروبات في إسكتلندا",
    "football in cuba": "كرة القدم في كوبا",
    "football in yucatán": "كرة القدم في ولاية يوكاتان",
    "footballers in romania": "لاعبو كرة قدم في رومانيا",
    "former populated places in hormozgan province": "أماكن كانت مأهولة في محافظة هرمزغان",
    "forts in jharkhand": "حصون في جهارخاند",
    "freedom of expression in india": "حرية التعبير في الهند",
    "french expatriate handball playerss in germany": "لاعبو كرة يد فرنسيون مغتربون في ألمانيا",
    "gabonese expatriates in france": "غابونيون مغتربون في فرنسا",
    "georgian architecture in wyoming": "عمارة جورجية في وايومنغ",
    "government buildings in manhattan": "مبان حكومية في مانهاتن",
    "guinean expatriate sports-people in romania": "رياضيون غينيون مغتربون في رومانيا",
    "haitian expatriates in romania": "هايتيون مغتربون في رومانيا",
    "handball in 1550 summer youth olympics": "كرة اليد في الألعاب الأولمبية الشبابية الصيفية 1550",
    "heads of universities and colleges in zimbabwe": "قادة جامعات وكليات في زيمبابوي",
    "health in british columbia": "الصحة في كولومبيا البريطانية",
    "high schools in india": "مدارس ثانوية في الهند",
    "hotels in italy": "فنادق في إيطاليا",
    "hotels in republic-of ireland": "فنادق في جمهورية أيرلندا",
    "ice hockey venues in ottawa": "ملاعب هوكي الجليد في أوتاوا",
    "indigenous peoples in querétaro": "شعوب أصلية في ولاية كويريتارو",
    "internet in el salvador": "إنترنت في السلفادور",
    "january 1550 in china": "يناير 1550 في الصين",
    "january 1550 in united kingdom": "يناير 1550 في المملكة المتحدة",
    "judo competitions in serbia": "منافسات جودو في صربيا",
    "judo in south africa": "الجودو في جنوب إفريقيا",
    "july 1550 in australia": "يوليو 1550 في أستراليا",
    "june 1550 in united states": "يونيو 1550 في الولايات المتحدة",
    "kurdish diaspora in united states": "شتات كردي في الولايات المتحدة",
    "legislators in india": "مشرعون في الهند",
    "lists of buildings and structures in california": "قوائم مبان ومنشآت في كاليفورنيا",
    "lists of legislators in india": "قوائم مشرعون في الهند",
    "lists of mayors of places in nova scotia": "قوائم رؤساء بلديات في نوفا سكوشا",
    "lists of roads in united kingdom": "قوائم طرقات في المملكة المتحدة",
    "lithuanian expatriate sports-people in australia": "رياضيون ليتوانيون مغتربون في أستراليا",
    "local politicians in united kingdom": "سياسيون محليون في المملكة المتحدة",
    "local-elections in india": "انتخابات محلية في الهند",
    "manslaughter in united states": "قتل خطأ في الولايات المتحدة",
    "march 1550 in oceania": "مارس 1550 في أوقيانوسيا",
    "maritime incidents in december 1550": "حوادث بحرية في ديسمبر 1550",
    "martial arts in montenegro": "الفنون القتالية في الجبل الأسود",
    "masonic buildings in iowa": "مبان ماسونية في آيوا",
    "mass shootings in africa": "إطلاق نار عشوائي في إفريقيا",
    "mass shootings in oceania": "إطلاق نار عشوائي في أوقيانوسيا",
    "mayors of places in nova scotia": "رؤساء بلديات في نوفا سكوشا",
    "men's football leagues in algeria": "دوريات كرة القدم للرجال في الجزائر",
    "mexican expatriates in belarus": "مكسيكيون مغتربون في روسيا البيضاء",
    "military and war museums in tennessee": "متاحف عسكرية وحربية في تينيسي",
    "military facilities on the-national-register-of-historic-places in indiana": "مرافق عسكرية في السجل الوطني للأماكن التاريخية في إنديانا",
    "military operations of american civil war in north dakota": "عمليات عسكرية في الحرب الأهلية الأمريكية في داكوتا الشمالية",
    "millennia in peru": "ألفيات في بيرو",
    "mines in devon": "مناجم في ديفون",
    "montserratian expatriates in england": "مونتسراتيون مغتربون في إنجلترا",
    "monuments and memorials in dorset": "معالم أثرية ونصب تذكارية في دورست",
    "monuments and memorials in northumberland": "معالم أثرية ونصب تذكارية في نورثمبرلاند",
    "monuments and memorials in tyne and wear": "معالم أثرية ونصب تذكارية في تاين ووير",
    "motorsport venues in massachusetts": "ملاعب رياضة محركات في ماساتشوستس",
    "motorsport venues in scotland": "ملاعب رياضة محركات في إسكتلندا",
    "municipalities in gjirokastër county": "بلديات في مقاطعة غيروكاستر",
    "murder in dublin (city)": "قتل في دبلن",
    "murder in istanbul": "قتل في إسطنبول",
    "murders in north america": "جرائم قتل في أمريكا الشمالية",
    "murders in russia": "جرائم قتل في روسيا",
    "museums in indianapolis": "متاحف في إنديانابوليس",
    "music venues in paraguay": "صالات الموسيقى في باراغواي",
    "national natural landmarks in alaska": "معالم طبيعية وطنية في ألاسكا",
    "natural disasters in united states": "كوارث طبيعية في الولايات المتحدة",
    "neighbourhoods in germany": "أحياء في ألمانيا",
    "november 1550 in argentina": "نوفمبر 1550 في الأرجنتين",
    "october 1550 in asia": "أكتوبر 1550 في آسيا",
    "october 1550 in canada": "أكتوبر 1550 في كندا",
    "october 1550 in europe": "أكتوبر 1550 في أوروبا",
    "october 1550 in japan": "أكتوبر 1550 في اليابان",
    "opera houses on the-national-register-of-historic-places in minnesota": "دور أوبرا في السجل الوطني للأماكن التاريخية في منيسوتا",
    "paintings in ireland": "لوحات في أيرلندا",
    "paleontology in connecticut": "علم الأحياء القديمة في كونيتيكت",
    "parks in county waterford": "متنزهات في مقاطعة وترفورد",
    "parks in taiwan": "متنزهات في تايوان",
    "pneumonia in oklahoma": "الالتهاب الرئوي في أوكلاهوما",
    "political controversies in yugoslavia": "خلافات سياسية في يوغسلافيا",
    "political parties in new hampshire": "أحزاب سياسية في نيوهامشير",
    "populated places in artigas department": "أماكن مأهولة في إدارة أرتيغاس",
    "populated places in cagayan valley": "أماكن مأهولة في وادي كاغيان",
    "populated places in city of zagreb": "أماكن مأهولة في مدينة زغرب",
    "presbyterianism in philippines": "مشيخية في الفلبين",
    "presidential-elections in italy": "انتخابات رئاسية في إيطاليا",
    "private schools in west yorkshire": "مدارس خاصة في غرب يوركشاير",
    "public education in maryland": "تعليم عمومي في ماريلند",
    "pubs in cumbria": "حانات في كمبريا",
    "racism in middle east": "عنصرية في الشرق الأوسط",
    "radio in gambia": "راديو في غامبيا",
    "radio in georgia (country)": "راديو في جورجيا",
    "radio stations in vermont": "محطات إذاعية في فيرمونت",
    "railway accidents in 1550s": "حوادث سكك حديد في عقد 1550",
    "railway stations in canada": "محطات السكك الحديدية في كندا",
    "railway stations in japan": "محطات السكك الحديدية في اليابان",
    "railway stations in netherlands": "محطات السكك الحديدية في هولندا",
    "railway stations in new zealand": "محطات السكك الحديدية في نيوزيلندا",
    "railway stations in north korea": "محطات السكك الحديدية في كوريا الشمالية",
    "railway stations in russia": "محطات السكك الحديدية في روسيا",
    "railway stations in united kingdom": "محطات السكك الحديدية في المملكة المتحدة",
    "railway stations in united states": "محطات السكك الحديدية في الولايات المتحدة",
    "religion in central macedonia": "الدين في إقليم مقدونيا الوسطى",
    "religion in hanoi": "الدين في هانوي",
    "religion in south america": "الدين في أمريكا الجنوبية",
    "religion in united states": "الدين في الولايات المتحدة",
    "religious buildings and structures in minnesota": "مبان ومنشآت دينية في منيسوتا",
    "research institutes in jordan": "معاهد أبحاث في الأردن",
    "reservoirs in irkutsk oblast": "خزانات مائية في إركوتسك أوبلاست",
    "roads in dnipro": "طرقات في دنيبروبتروفسك",
    "roads in united kingdom": "طرقات في المملكة المتحدة",
    "roman catholic archbishops in colombia": "رؤساء أساقفة رومان كاثوليك في كولومبيا",
    "roman catholic churches in umbria": "كنائس رومانية كاثوليكية في أومبريا",
    "rugby league in africa": "دوري الرجبي في إفريقيا",
    "rugby union leagues in japan": "اتحاد دوري الرجبي في اليابان",
    "russian expatriates in united arab emirates": "روس مغتربون في الإمارات العربية المتحدة",
    "saint kitts and nevis in summer olympics": "سانت كيتس ونيفيس في الألعاب الأولمبية الصيفية",
    "schools in turkey": "مدارس في تركيا",
    "science and technology in romania": "العلوم والتقانة في رومانيا",
    "science in art": "العلم في الفن",
    "senegal in world aquatics championships": "السنغال في بطولة العالم للرياضات المائية",
    "senegalese expatriate basketball people in kosovo": "أعلام كرة سلة سنغاليون مغتربون في كوسوفو",
    "september 1550 in canada": "سبتمبر 1550 في كندا",
    "september 1550 in north america": "سبتمبر 1550 في أمريكا الشمالية",
    "shipping in north america": "نقل بحري في أمريكا الشمالية",
    "shopping malls in ukraine": "مراكز تسوق في أوكرانيا",
    "softball in new york (state)": "الكرة اللينة في ولاية نيويورك",
    "solar power stations in nigeria": "محطات طاقة شمسية في نيجيريا",
    "spain in uefa euro 1550": "إسبانيا في بطولة أمم أوروبا 1550",
    "spanish expatriates in solomon islands": "إسبان مغتربون في جزر سليمان",
    "sport in khartoum": "الرياضة في الخرطوم",
    "sport in ottoman empire": "الرياضة في الدولة العثمانية",
    "sport in tuzla": "الرياضة في توزلا",
    "sport in veria": "الرياضة في فيريا",
    "sports coaches in utah": "مدربو رياضة في يوتا",
    "sports competitions in montevideo": "منافسات رياضية في مونتفيدو",
    "sports venues in queensland": "ملاعب رياضية في كوينزلاند",
    "sports-people in ireland": "رياضيون في أيرلندا",
    "studios in greece": "استديوهات في اليونان",
    "studios in poland": "استديوهات في بولندا",
    "synagogues in switzerland": "كنس في سويسرا",
    "television stations in virginia": "محطات تلفزيونية في فرجينيا",
    "tennis tournaments in serbia-and-montenegro": "بطولات كرة مضرب في صربيا والجبل الأسود",
    "terrorism deaths in malta": "وفيات بسبب الإرهاب في مالطا",
    "togolese expatriates in israel": "توغويون مغتربون في إسرائيل",
    "togolese expatriates in turkey": "توغويون مغتربون في تركيا",
    "tourism in united kingdom": "سياحة في المملكة المتحدة",
    "tourist attractions in almaty": "مواقع جذب سياحي في ألماتي",
    "tourist attractions in amman": "مواقع جذب سياحي في عمان",
    "tourist attractions in dâmbovița county": "مواقع جذب سياحي في مقاطعة دامبوفيتا",
    "tourist attractions in marinduque": "مواقع جذب سياحي في ماريندوك",
    "track and field athletes in 1550 summer paralympics": "رياضيو المسار والميدان في الألعاب البارالمبية الصيفية 1550",
    "transport in kirov oblast": "نقل في أوبلاست كيروف",
    "transport in newfoundland and labrador": "نقل في نيوفاوندلاند واللابرادور",
    "transport in oxford": "نقل في أكسفورد",
    "transport in ternopil oblast": "نقل في تيرنوبل أوبلاست",
    "transport museums in zambia": "متاحف نقل في زامبيا",
    "trinidad and tobago expatriate sports-people in greece": "رياضيون ترنيداديون مغتربون في اليونان",
    "tunisian expatriate sports-people in libya": "رياضيون تونسيون مغتربون في ليبيا",
    "unincorporated communities in united states": "مجتمعات فردية في الولايات المتحدة",
    "universities and colleges in isabela (province)": "جامعات وكليات في ايزابلا (محافظة)",
    "universities and colleges in montpellier": "جامعات وكليات في مونبلييه",
    "victims of aviation accidents or incidents in dominican republic": "ضحايا حوادث طيران في جمهورية الدومينيكان",
    "vietnamese diaspora in canada": "شتات فيتنامي في كندا",
    "villages in datia district": "قرى في مقاطعة داتيا",
    "villages in north macedonia": "قرى في مقدونيا الشمالية",
    "villages in poltava oblast": "قرى في بولتافا أوبلاست",
    "villages in ramanagara district": "قرى في مقاطعة رامانجارا",
    "vocational education in uganda": "تعليم مهني في أوغندا",
    "volleyball clubs in italy": "أندية كرة طائرة في إيطاليا",
    "volleyball playerss in 1550 summer paralympics": "لاعبو كرة طائرة في الألعاب البارالمبية الصيفية 1550",
    "waste management in brazil": "إدارة المخلفات في البرازيل",
    "water sports in tanzania": "رياضات مائية في تنزانيا",
    "women's cricket teams in india": "فرق الكريكت للسيدات في الهند",
    "women's football in slovakia": "كرة القدم للسيدات في سلوفاكيا",
    "women's futsal in bolivia": "كرة صالات للسيدات في بوليفيا",
    "years in curaçao": "سنوات في كوراساو",
    "years of 20th century in australia": "سنوات القرن 20 في أستراليا",
    "youth sport in british virgin islands": "رياضة شبابية في جزر العذراء البريطانية",
}


to_test = [
    ("test_data_list_in", data_list_in),
]


@pytest.mark.parametrize("category, separator, output", data_list, ids=[x[0] for x in data_list])
@pytest.mark.fast
def test_simple_2(category: str, separator: str, output: str) -> None:
    label = find_ar_label(category, separator, use_event2=False)
    assert label == output


@pytest.mark.parametrize("category, output", data_list_in.items(), ids=data_list_in.keys())
@pytest.mark.fast
def test_data_list_in(category: str, output: str) -> None:
    label = find_ar_label(category, " in ", use_event2=False)
    assert label == output


@pytest.mark.parametrize("name,data", to_test)
# @pytest.mark.skip
@pytest.mark.dump
def test_dump_it(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, lambda k: find_ar_label(k, " in ", use_event2=False), name)
    dump_diff(diff_result, name)

    # dump_same_and_not_same(data, expected, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



"""
Tests
"""

import re

import pytest
from load_one_data import dump_diff, one_dump_test

from ArWikiCats.genders_resolvers.nat_genders_pattern_multi import genders_jobs_resolver

test_job_bot_data = {
    "actors": "ممثلون وممثلات",
    "actresses": "ممثلات",
    "male actors": "ممثلون",
    "yemeni actresses": "ممثلات يمنيات",
    "yemeni actors": "ممثلون وممثلات يمنيون",
    "yemeni male actors": "ممثلون يمنيون",
    "boxers": "ملاكمون وملاكمات",
    "female boxers": "ملاكمات",
    "male boxers": "ملاكمون",
    "women boxers": "ملاكمات",
    "yemeni boxers": "ملاكمون وملاكمات يمنيون",
    "yemeni female boxers": "ملاكمات يمنيات",
    "yemeni male boxers": "ملاكمون يمنيون",
    "yemeni women's boxers": "ملاكمات يمنيات",
    "female singers": "مغنيات",
    "male singers": "مغنون",
    "singers": "مغنون ومغنيات",
    "women singers": "مغنيات",
    "yemeni male singers": "مغنون يمنيون",
    "yemeni singers": "مغنون ومغنيات يمنيون",
    "yemeni female singers": "مغنيات يمنيات",
    "yemeni women singers": "مغنيات يمنيات",
}

test_data2 = {
    "classical composers": "ملحنون وملحنات كلاسيكيون",
    "male classical singers": "مغنون كلاسيكيون",
    "female classical singers": "مغنيات كلاسيكيات",
    "yemeni male classical composers": "ملحنون كلاسيكيون يمنيون",
    "yemeni classical composers": "ملحنون وملحنات كلاسيكيون يمنيون",
    "yemeni female classical composers": "ملحنات كلاسيكيات يمنيات",
    # classical all keys (6 possibilities)
    "classical boxers": "ملاكمون وملاكمات كلاسيكيون",
    "male classical boxers": "ملاكمون كلاسيكيون",
    "female classical boxers": "ملاكمات كلاسيكيات",
    "yemeni male classical boxers": "ملاكمون كلاسيكيون يمنيون",
    "yemeni womens classical boxers": "ملاكمات كلاسيكيات يمنيات",
    "yemeni classical boxers": "ملاكمون وملاكمات كلاسيكيون يمنيون",
    # other keys
    "male guitarists": "عازفو قيثارة",
    "women guitarists": "عازفات قيثارة",
    "guitarists": "عازفو وعازفات قيثارة",
    "yemeni guitarists": "عازفو وعازفات قيثارة يمنيون",
    "yemeni male guitarists": "عازفو قيثارة يمنيون",
    "yemeni female guitarists": "عازفات قيثارة يمنيات",
    "male yemeni guitarists": "عازفو قيثارة يمنيون",
    "female yemeni guitarists": "عازفات قيثارة يمنيات",
}


@pytest.mark.parametrize("category, expected", test_job_bot_data.items(), ids=test_job_bot_data.keys())
@pytest.mark.fast
def test_job_bot(category: str, expected: str) -> None:
    label = genders_jobs_resolver(category)
    assert label == expected


@pytest.mark.parametrize("category, expected", test_data2.items(), ids=test_data2.keys())
@pytest.mark.fast
def test_job_bot2(category: str, expected: str) -> None:
    label = genders_jobs_resolver(category)
    assert label == expected
